/*
 * Copyright (c) 2015 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kniss
 *
 * This file is part of de.bsvrz.kex.tls.osi7.conversion.Fg001Default
 *
 * de.bsvrz.kex.tls.osi7.conversion.Fg001Default is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.Fg001Default is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with de.bsvrz.kex.tls.osi7.conversion.Fg001Default.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Diese Datei ist Teil von de.bsvrz.kex.tls.osi7.conversion.Fg001Default.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.Fg001Default ist Freie Software: Sie können es unter den Bedingungen
 *  der GNU General Public License, wie von der Free Software Foundation,
 *  Version 3 der Lizenz oder (nach Ihrer Wahl) jeder späteren
 *  veröffentlichten Version, weiterverbreiten und/oder modifizieren.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.Fg001Default wird in der Hoffnung, dass es nützlich sein wird, aber
 *  OHNE JEDE GEWÄHRLEISTUNG, bereitgestellt; sogar ohne die implizite
 *  Gewährleistung der MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
 *  Siehe die GNU General Public License für weitere Details.
 *
 *  Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
 *  Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * inovat, Dipl.-Ing. H. C. Kniss
 * An der Krautwiese 37
 * D-53783 Eitorf
 * +49 (0)2243 8464 193
 * info@inovat.de
 * www.inovat.de
 */



package de.bsvrz.kex.tls.osi7.conversion;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.config.IntegerValueState;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.DataDescription;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.kex.tls.osi7.*;
import de.bsvrz.kex.tls.osi7.deausfallueberwachung.DeAusfallUeberwachung;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.hexdump.HexDumper;
import de.bsvrz.sys.funclib.operatingMessage.MessageGrade;
import de.bsvrz.sys.funclib.operatingMessage.MessageState;
import de.bsvrz.sys.funclib.operatingMessage.MessageType;

//~ JDK IMPORTE ===============================================================

import java.util.ArrayList;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.List;

//~ KLASSEN ===================================================================

/**
 * Umsetungsmodul für die FG 1, Standard (alle Typen der FG 1 gemäß TLS 2002). Wird standardmäßig für alle FG 1 De
 * verwendet, bei denen keine spezielle Umsezungsklasse in der Konfiguration angegeben wurde.
 * <p>
 * Erweiterung: unterstützt auch nachgelieferte Telegramme (Standard ID+32)
 *
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class Fg001Default extends FgAllDefault {

    // ------------------------------------------------------------------------
    // VARIABLENDEKLARATIONEN
    // ------------------------------------------------------------------------
    // Sonstige ---------------------------------------------------------------

    /** DebugLogger für Debug-Ausgaben */
    private static final Debug debug = Debug.getLogger();

    //~ FELDER ================================================================

    // Private ----------------------------------------------------------------

    /**
     * Art der Mittelwertbildung, die bei diesem De eingestellt ist. Wird sowohl beim Setzen der Betriebs- parameter als
     * auch beim Empfang der Rückmeldung (sofern diese erfolgt) angepasst. -1 = unbekannt 0 = gleitende Mittelwertbildung 1
     * = arithmetische Mittelwertbildung
     */
    private int _kindOfAverage = -1;  // initial auf undefiniert

    /**
     * Vorbelegung der Geschwindigkeitsklassen für BPA gemäß BASt für Langzeitdaten Version 24. Wird beim Empfang der
     * Rückmeldung (sofern diese erfolgt) angepasst.
     */
    private int[] _vGrenzBPA = { 40, 50, 60, 70, 80, 90, 100, 110, 120 };

    /**
     * Vorbelegung der Geschwindigkeitsklassen für LVo gemäß BASt für Langzeitdaten Version 24. Wird beim Empfang der
     * Rückmeldung (sofern diese erfolgt) angepasst.
     */
    private int[] _vGrenzLVo = { 40, 50, 60, 70, 80, 90, 100, 110, 120, 130, 140, 150, 160, 170, 180 };

    /**
     * Vorbelegung der Geschwindigkeitsklassen für SVG gemäß BASt für Langzeitdaten Version 24. Wird beim Empfang der
     * Rückmeldung (sofern diese erfolgt) angepasst.
     */
    private int[] _vGrenzSGV = { 40, 50, 60, 70, 80, 90, 100, 110, 120 };

    /**
     * Tabelle für die Doppelauswertung von Typ 79. Die ATG-ASP Kombinationen werden bereits durch Fg001Default
     * (Superklassen) als Quelle angemeldet und dürfen deshalb nicht nochmal an subscribeAllData() übergeben werden! Die
     * folgenden Einträge müssen deshalb direkt in die Liste des DeConversionModul (this.getTlsToDavList()) geschrieben
     * werden.
     */
    private final Object[][] tlsToDavSpecial = new Object[][] {

        // Attributgruppe, Aspekt, Fg, Typ, Id, ObjektTyp

        /**
         */
    };

    /**
     * Tabelle, in der das Verhalten beim Empfang von TLS De-Blöcken eingetragen wird. Jede Tabellenzeile hat folgenden
     * Aufbau:
     * <pre>
     * "Attributgruppe (Pid)", "Aspekt (Pid)", "Fg", "Typ", "Id", "ObjektTyp"
     * z.B.
     * "atg.tlsGloKanalSteuerung", "asp.tlsAntwort", "1", "29", "2", "typ.deLve"
     * </pre>
     * Die Auswertung erfolgt dabei wie folgt: <ul> <li> Für jede Attributguppen/Aspekt Kombination erfolgt eine
     * Sendeanmeldung als Quelle.</li> <li> In der Methode {@link #processDeBlock} wird für jede zum De-Block passende
     * Fg/Id/Typ-Kombination eine Methode aufgerufen, deren Namen aus dem Tabelleneintrag wie folgt gebildet wird (hier für
     * den Beispieleintrag):<br> <code>Fg001Typ029Id002AtgTlsGloKanalSteuerungAspTlsAntwort(DeBlock, Data,
     * DataDescription)</code><br> Dabei enthält der <code>deBlock</code> die Daten des zu verarbeitenden De-Blocks und
     * <code>data</code> ein Datenobjekt der passenden Attributgruppen/Aspekt-Kombination, welchem direkt die Inhalte des
     * De-Blocks zugewiesen werden können.<code>DataDescription</code> enthält die passende {@link de.bsvrz.dav.daf.main.DataDescription} für die
     * zu sendenden Daten.</li> <li> Für jede Attributguppen/Aspekt Kombination erfolgt eine Sendeanmeldung als Quelle.
     * Sind mehrere passende Eintrage vorhanden, werden entsprechend mehrere Methodenaufrufe durchgeführt. Dadurch kann ein
     * De-Block mehrfach ausgewert und an verschiedene Attributgruppen weitergerleitet werden (z.B. protokollnahe
     * TLS-Attributgruppe und Attributgruppe eine Fachmodells):</li> <li> Ein Eintrag von "255" entspricht dabei einer
     * "Wildcard" (passt immer). </ul>
     */
    private final Object[][] tlsToDav = new Object[][] {

        // Attributgruppe, Aspekt, Fg, Typ, Id, ObjektTyp
        { "atg.tlsGloDeFehler", "asp.tlsAntwort", "1", "1", "1", "typ.deLve" },                         //
        { "atg.tlsGloDeFehler", "asp.tlsAntwort", "1", "1", "33", "typ.deLve" },                        //
        { "atg.tlsGloKanalSteuerung", "asp.parameterIst", "255", "29", "2", "typ.deLve" },              //
        { "atg.tlsGloKanalSteuerung", "asp.parameterIst", "255", "29", "34", "typ.deLve" },             //
        { "atg.tlsGloGeographischeKenndaten", "asp.tlsZustand", "255", "36", "3", "typ.deLve" },        //
        { "atg.tlsGloGeographischeKenndaten", "asp.tlsZustand", "255", "36", "35", "typ.deLve" },       //
        { "atg.tlsLveErgänzendeDeFehlerMeldung", "asp.tlsAntwort", "1", "14", "1", "typ.deLve" },       //
        { "atg.tlsLveErgänzendeDeFehlerMeldung", "asp.tlsAntwort", "1", "14", "33", "typ.deLve" },      //
        { "atg.tlsLveNegativeQuittung", "asp.tlsAntwort", "1", "16", "2", "typ.deLve" },                //
        { "atg.tlsLveNegativeQuittung", "asp.tlsAntwort", "1", "16", "34", "typ.deLve" },               //
        { "atg.tlsLvePositiveQuittung", "asp.tlsAntwort", "1", "28", "2", "typ.deLve" },                //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "49", "4", "typ.deLve" },     //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "49", "36", "typ.deLve" },    //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "50", "4", "typ.deLve" },     //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "50", "36", "typ.deLve" },    //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "51", "4", "typ.deLve" },     //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "51", "36", "typ.deLve" },    //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "52", "4", "typ.deLve" },     //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "52", "36", "typ.deLve" },    //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "53", "4", "typ.deLve" },     //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "53", "36", "typ.deLve" },    //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "113", "4", "typ.deLve" },    //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "113", "36", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "114", "4", "typ.deLve" },    //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "114", "36", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "115", "4", "typ.deLve" },    //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "115", "36", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "116", "4", "typ.deLve" },    //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "116", "36", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "117", "4", "typ.deLve" },    //
        { "atg.tlsLveErgebnisMeldungVersion0Bis4", "asp.tlsAntwort", "1", "117", "36", "typ.deLve" },   //
        { "atg.tlsLveKfzEinzelDaten", "asp.tlsAntwort", "1", "63", "4", "typ.deLve" },                  //
        { "atg.tlsLveKfzEinzelDaten", "asp.tlsAntwort", "1", "63", "36", "typ.deLve" },                 //
        { "atg.kfzEinzelDatenFs", "asp.externeErfassung", "1", "63", "4", "typ.fahrStreifen" },         //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "65", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "66", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "67", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "68", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "69", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "70", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "71", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "72", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "73", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "74", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "75", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "76", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "77", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "78", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "65", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "66", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "67", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "68", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "69", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "70", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "71", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "72", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "73", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "74", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "75", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "76", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "77", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "78", "36", "typ.deLve" },

        // Ergänzungen für Langzeitdaten FG 1 / Typ 79
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "79", "4", "typ.deLve" },   //
        { "atg.tlsLveErgebnisMeldungVersion10Bis23", "asp.tlsAntwort", "1", "79", "36", "typ.deLve" },  //
        { "atg.tlsLveErgebnisMeldungVersion24", "asp.tlsAntwort", "1", "79", "4", "typ.deLve" },        //
        { "atg.tlsLveErgebnisMeldungVersion24", "asp.tlsAntwort", "1", "79", "36", "typ.deLve" },

        // Ende Ergänzungen für Langzeitdaten FG 1 / Typ 79
        { "atg.tlsSveErgebnisMeldungVersion0Bis1", "asp.tlsAntwort", "1", "97", "4", "typ.deLve" },                                      //
        { "atg.tlsSveErgebnisMeldungVersion0Bis1", "asp.tlsAntwort", "1", "97", "36", "typ.deLve" },                                     //
        { "atg.tlsLveBetriebsParameter", "asp.parameterIst", "1", "32", "3", "typ.deLve" },                                              //
        { "atg.tlsLveBetriebsParameter", "asp.parameterIst", "1", "32", "35", "typ.deLve" },                                             //
        { "atg.tlsSveBetriebsParameter", "asp.parameterIst", "1", "34", "3", "typ.deLve" },                                              //
        { "atg.tlsSveBetriebsParameter", "asp.parameterIst", "1", "34", "35", "typ.deLve" },                                             //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenPkwÄ", "asp.parameterIst", "1", "37", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenPkwÄ", "asp.parameterIst", "1", "37", "35", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenLkwÄ", "asp.parameterIst", "1", "37", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenLkwÄ", "asp.parameterIst", "1", "37", "35", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwG", "asp.parameterIst", "1", "38", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwG", "asp.parameterIst", "1", "38", "35", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwA", "asp.parameterIst", "1", "38", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwA", "asp.parameterIst", "1", "38", "35", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkw", "asp.parameterIst", "1", "38", "3", "typ.deLve" },         //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkw", "asp.parameterIst", "1", "38", "35", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwK", "asp.parameterIst", "1", "38", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwK", "asp.parameterIst", "1", "38", "35", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBus", "asp.parameterIst", "1", "38", "3", "typ.deLve" },         //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBus", "asp.parameterIst", "1", "38", "35", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzNk", "asp.parameterIst", "1", "38", "3", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzNk", "asp.parameterIst", "1", "38", "35", "typ.deLve" },      //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkw", "asp.parameterIst", "1", "38", "3", "typ.deLve" },         //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkw", "asp.parameterIst", "1", "38", "35", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwA", "asp.parameterIst", "1", "38", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwA", "asp.parameterIst", "1", "38", "35", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSattelKfz", "asp.parameterIst", "1", "38", "3", "typ.deLve" },   //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSattelKfz", "asp.parameterIst", "1", "38", "35", "typ.deLve" },  //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKrad", "asp.parameterIst", "1", "38", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKrad", "asp.parameterIst", "1", "38", "35", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLfw", "asp.parameterIst", "1", "38", "3", "typ.deLve" },         //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLfw", "asp.parameterIst", "1", "38", "35", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwÄ", "asp.parameterIst", "1", "38", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwÄ", "asp.parameterIst", "1", "38", "35", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwÄ", "asp.parameterIst", "1", "38", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwÄ", "asp.parameterIst", "1", "38", "35", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfz", "asp.parameterIst", "1", "38", "3", "typ.deLve" },         //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfz", "asp.parameterIst", "1", "38", "35", "typ.deLve" },        //

        // Ergänzungen für Langzeitdaten FG 1 / Typ 79
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLVo", "asp.parameterIst", "1", "38", "3", "typ.deLve" },   //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLVo", "asp.parameterIst", "1", "38", "35", "typ.deLve" },  //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSGV", "asp.parameterIst", "1", "38", "3", "typ.deLve" },   //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSGV", "asp.parameterIst", "1", "38", "35", "typ.deLve" },  //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBPA", "asp.parameterIst", "1", "38", "3", "typ.deLve" },   //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBPA", "asp.parameterIst", "1", "38", "35", "typ.deLve" },  //

        // Ende Ergänzungen für Langzeitdaten FG 1 / Typ 79
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "49", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "49", "36", "typ.fahrStreifen" },                          //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "50", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "50", "36", "typ.fahrStreifen" },                          //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "51", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "51", "36", "typ.fahrStreifen" },                          //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "52", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "52", "36", "typ.fahrStreifen" },                          //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "53", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "53", "36", "typ.fahrStreifen" },                          //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "113", "4", "typ.fahrStreifen" },                          //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "113", "36", "typ.fahrStreifen" },                         //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "114", "4", "typ.fahrStreifen" },                          //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "114", "36", "typ.fahrStreifen" },                         //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "115", "4", "typ.fahrStreifen" },                          //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "115", "36", "typ.fahrStreifen" },                         //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "116", "4", "typ.fahrStreifen" },                          //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "116", "36", "typ.fahrStreifen" },                         //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "117", "4", "typ.fahrStreifen" },                          //
        { "atg.verkehrsDatenKurzZeitIntervall", "asp.externeErfassung", "1", "117", "36", "typ.fahrStreifen" },                         //
        { "atg.verkehrsDatenKurzZeitGeschwindigkeitsKlassenIntervall", "asp.externeErfassung", "1", "53", "4", "typ.fahrStreifen" },    //
        { "atg.verkehrsDatenKurzZeitGeschwindigkeitsKlassenIntervall", "asp.externeErfassung", "1", "53", "36", "typ.fahrStreifen" },   //
        { "atg.verkehrsDatenKurzZeitGeschwindigkeitsKlassenIntervall", "asp.externeErfassung", "1", "117", "4", "typ.fahrStreifen" },   //
        { "atg.verkehrsDatenKurzZeitGeschwindigkeitsKlassenIntervall", "asp.externeErfassung", "1", "117", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "65", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "66", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "67", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "68", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "69", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "70", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "71", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "72", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "73", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "74", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "75", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "76", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "77", "4", "typ.fahrStreifen" },                           //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "78", "4", "typ.fahrStreifen" },                           //

        // Ergänzungen für Langzeitdaten FG 1 / Typ 79
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "79", "4", "typ.fahrStreifen" },                             //
        { "atg.verkehrsDatenLangZeitIntervallGeschwindigkeitVerteilungFs", "asp.externeErfassung", "1", "79", "4", "typ.fahrStreifen" },  //

        // Ende Ergänzungen für Langzeitdaten FG 1 / Typ 79
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "65", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "66", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "67", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "68", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "69", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "70", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "71", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "72", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "73", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "74", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "75", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "76", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "77", "36", "typ.fahrStreifen" },  //
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "78", "36", "typ.fahrStreifen" },  //

        // Ergänzungen für Langzeitdaten FG 1 / Typ 79
        { "atg.verkehrsDatenLangZeitIntervall", "asp.externeErfassung", "1", "79", "36", "typ.fahrStreifen" },                             //
        { "atg.verkehrsDatenLangZeitIntervallGeschwindigkeitVerteilungFs", "asp.externeErfassung", "1", "79", "36", "typ.fahrStreifen" },  //

        // Ende Ergänzungen für Langzeitdaten FG 1 / Typ 79
    };

    /**
     * Tabelle, in der das Verhalten beim Empfang von Attributgruppen eingetragen wird. Jede Tabellenzeile hat folgenden
     * Aufbau:
     * <pre>
     * "Attributgruppe (Pid)", "Aspekt (Pid)", "Fg", "Typ", "Id", "ObjektTyp"
     * z.B.
     * "atg.tlsGloKanalSteuerung", "asp.parameterSoll", "1", "29", "2", "typ.deLve"
     * </pre>
     * Die Auswertung erfolgt dabei wie folgt: <ul> <li> Für jede Attributguppen/Aspekt Kombination erfolgt eine
     * Empfangsanmeldung als Empfänger.</li> <li> In der Methode {@link #update} wird für jede zur
     * Attributgruppen/Aspket-Kombination passende Kombination eine Methode aufgerufen, deren Namen aus dem Tabelleneintrag
     * wie folgt gebildet wird (hier für den Beispieleintrag):<br> <code>Fg001Typ029Id002AtgTlsGloKanalSteuerungAspParameterSoll(ResultData)</code><br>
     * Dabei enthält <code>ResultData</code> die Daten der zu verarbeitenden ATG/ASP-Kombination.</li> <li> Für jede
     * Attributguppen/Aspekt Kombination erfolgt eine Empfangsanmeldung als Empfänger. Sind mehrere passende Eintrage
     * vorhanden, werden entsprechend mehrere Methodenaufrufe durchgeführt. Dadurch können mehrere ATG/ASP-Kombinationen in
     * einen De-Block abgebildet werden (z.B. protokollnahe TLS-Attributgruppe und Attributgruppe eines Fachmodells):</li>
     * <li> Ein Eintrag von "255" entspricht dabei einer "Wildcard" (passt immer). </ul>
     */
    private final Object[][] davToTls = new Object[][] {

        // Attributgruppe, Aspekt, Fg, Typ, Id, ObjektTyp
        { "atg.tlsGloDeBlockAbruf", "asp.tlsAbruf", "255", "255", "255", "typ.deLve" },                                                  //
        { "atg.tlsGloDeBlockSenden", "asp.tlsVorgabe", "255", "255", "255", "typ.deLve" },                                               //
        { "atg.tlsGloKanalSteuerung", "asp.parameterSoll", "255", "29", "2", "typ.deLve" },                                              //
        { "atg.tlsGloGeographischeKenndaten", "asp.tlsVorgabe", "255", "36", "3", "typ.deLve" },                                         //
        { "atg.tlsLveAbrufPufferInhalt", "asp.tlsAbruf", "1", "20", "2", "typ.deLve" },                                                  //
        { "atg.tlsLveBetriebsParameter", "asp.parameterSoll", "1", "32", "3", "typ.deLve" },                                             //
        { "atg.tlsSveBetriebsParameter", "asp.parameterSoll", "1", "34", "3", "typ.deLve" },                                             //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenPkwÄ", "asp.parameterSoll", "1", "37", "3", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenLkwÄ", "asp.parameterSoll", "1", "37", "3", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwG", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwA", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkw", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwK", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBus", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzNk", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },      //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkw", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwA", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSattelKfz", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },  //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKrad", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLfw", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },        //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwÄ", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwÄ", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },       //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfz", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },        //

        // Ergänzungen für Langzeitdaten FG 1 / Typ 79
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLVo", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },  //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSGV", "asp.parameterSoll", "1", "38", "3", "typ.deLve" },  //
        { "atg.tlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBPA", "asp.parameterSoll", "1", "38", "3", "typ.deLve" }   //
    };

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    /**
     * Erzeugt ein Objekt vom Typ Fg001Default
     *
     * @param daf Datenverteilerverbindung.
     * @param eak Eak.
     * @param de  De.
     */
    public Fg001Default(ClientDavInterface daf, Eak eak, De de) {
        super(daf, eak, de);
        subscribeAllData(tlsToDav, davToTls);
    }

    //~ METHODEN ==============================================================

    /**
     * FG 1 : Typ: 1 Id: 1 Name: DE-Fehler (Antwort). Ergänzt globale Behandlung De-Fehler in {@link
     * #Fg255Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort}. Beim Empfang einer De-Gutmeldung wird die De initialisiert, indem
     * <ul> <li>LVE-kanalsteuerung {@link #Fg255Typ029Id002AtgTlsGloKanalSteuerungAspParameterSoll}</li>
     * <li>LVE-betriebsparameter{@link #Fg001Typ032Id003AtgTlsLveBetriebsParameterAspParameterSoll}</li> </ul> versendet
     * werden.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData        resultData     = super.Fg255Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort(deBlock, data, dataDescription);
        IntegerValueState DEFehlerStatus = data.getUnscaledValue("DEFehlerStatus").getState();

        if (DEFehlerStatus != null) {
            debug.fine("DEFehlerStatus: " + DEFehlerStatus.getName());

            if (DEFehlerStatus.getName().equals("ok")) {
                sendInitialDeBlock(deBlock.getKey(), 29, 2);  // LVE-Kanalsteuerung senden
                sendInitialDeBlock(deBlock.getKey(), 32, 3);  // LVE-Betriebsparameter senden
            } else {
                List<De> deList = new ArrayList<De>();

                deList.add(_de);
                TlsApplicationLayer.writeNoDataToUnreachableDe(deList, _eakConversionModul.getTimeStamp(), -1, "atg.tlsGloDeFehler");
            }
        }

        return resultData;
    }

    // ------------------------------------------------------------------------
    // SONSTIGE METHODEN
    // ------------------------------------------------------------------------

    /**
     * Entspricht {@link Fg001Default#Fg001Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert
     * gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ001Id033AtgTlsGloDeFehlerAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 1, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ001Id001AtgTlsGloDeFehlerAspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * FG 1 : Typ: 14 Id: 1 Name: Ergänzende DE-Fehlermeldung (Antwort) TLS-Datenbeschreibung:
     * <pre>
     * Position         Bezeichnung                             Erläuterung
     * Byte 1           Länge DE-Block                          [ 9..29 ]
     * Byte 2           Daten-Endgeräte-Kanal                   [ 1..254 ]
     * Byte 3           Typ der DE-Daten                        [ 14 ]
     * Byte 4           Herstellercode                          (s. Anh. 7, Kap.
     * 2)
     * Byte 5           Anzahl TLS  Fehlerbytes                [ 4 ]
     * Byte 6           TLS - Fehlerbyte 1                      Codierung siehe
     * unten
     * Byte 7           TLS - Fehlerbyte 2                      Codierung siehe
     * unten
     * Byte 8           TLS - Fehlerbyte 3                      Codierung siehe
     * unten
     * Byte 9           TLS - Fehlerbyte 4                      Codierung siehe
     * unten
     * Byte 10          Anzahl Hersteller Fehlerbytes           [ 0..20 ]
     * Byte 11          Hersteller-Fehlerbyte 1                 herstellerspez.
     * Codierung
     * Byte..           Hersteller-Fehlerbyte n
     * </pre>
     * Inhalt TLS-Fehlerbytes:<br> Die Fehlerbytes sind bitweise codiert. Jedes Bit definiert einen bestimmten Fehler,
     * wobei das Bit gleich 1 gesetzt ist.<br> Es können auch mehrere Bit gleichzeitig gesetzt werden. Der Inhalt der
     * Fehlerbytes ist optional. D.h. bei einer Realisierung dieses Telegrammtyps müssen vom Hersteller nicht alle in der
     * Tabelle definierten Fehlercodes erfüllt werden. Für spätere Definitionen reservierte Bits bzw. nicht verwendete Bits
     * sind gleich Null zu setzen.
     * <pre>
     *         Bit 7      Bit 6       Bit 5       Bit 4          Bit 3         Bit
     * 2       Bit 1       Bit 0
     * Byte 1  Reserve    Reserve     RNR am      Lokalbus       Reserve
     * Reserve     Reserve     Teilstörung
     *                                Lokalbus1   ausgefallen
     * Byte 2  Abgleich   Abgleich    Schleife 2  Schleife 1     Auswertung
     * Detektor    Subbus      Subbus
     *         Schleife   Schleife    defekt 2)   defekt 2)      gestört
     * gestört     RNR         ausgefallen
     *         2 2)       1 2)
     * Byte 3  Reserve    Reserve     Reserve     Reserve        Reserve
     * Reserve     Reserve     Reserve
     * Byte 4  Reserve    Reserve     Reserve     Reserve        Reserve
     * Reserve     Reserve     Reserve
     * </pre>
     * 1) nur in Verbindung mit Stö/SM=1 im Byte 4 der DE-Block-Struktur im Typ 1<br> 2) Schleife 1 und Schleife 2 sind die
     * 1. bzw. 2. Schleife einer Doppelschleife desselben Fahrstreifens, gezählt in Fahrtrichtung.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ014Id001AtgTlsLveErgänzendeDeFehlerMeldungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Herstellercode-Byte aus Telegramm ---------------------------------------------------------------------------
        int _Herstellercode_ = deBlock.getDeData().readUnsignedByteAsInt();

        data.getUnscaledValue("Hersteller").set(_Herstellercode_);

        // Fehler-Bytes aus Telegramm -----------------------------------------------------------------------------------
        deBlock.getDeData().readUnsignedByteAsInt();  // Anzahl der folgenden Bytes überlesen, da immer == 4 !

        int              _TlsFehler1_ = deBlock.getDeData().readUnsignedByteAsInt();
        int              _TlsFehler2_ = deBlock.getDeData().readUnsignedByteAsInt();
        int              _TlsFehler3_ = deBlock.getDeData().readUnsignedByteAsInt();
        int              _TlsFehler4_ = deBlock.getDeData().readUnsignedByteAsInt();
        Data.NumberArray _TlsFehler_  = data.getItem("FehlercodesTLS").getUnscaledArray("Fehler");

        _TlsFehler_.setLength(4);
        _TlsFehler_.getValue(0).set(_TlsFehler1_);
        _TlsFehler_.getValue(1).set(_TlsFehler2_);
        _TlsFehler_.getValue(2).set(_TlsFehler3_);
        _TlsFehler_.getValue(3).set(_TlsFehler4_);

        // Hersteller Fehler-Bytes aus Telegramm -----------------------------------------------------------------------
        int   count              = deBlock.getDeData().readUnsignedByteAsInt();
        int[] _HerstellerFehler_ = new int[count];

        for (int i = 0; i < count; i++) {
            _HerstellerFehler_[i] = deBlock.getDeData().readUnsignedByteAsInt();
        }

        Data.NumberArray _Fehler_ = data.getItem("FehlercodesHersteller").getUnscaledArray("Fehler");

        _Fehler_.setLength(count);

        for (int i = 0; i < count; i++) {
            _Fehler_.getValue(i).set(_HerstellerFehler_[i]);
        }

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ014Id001AtgTlsLveErgänzendeDeFehlerMeldungAspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ014Id033AtgTlsLveErgänzendeDeFehlerMeldungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 1, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ014Id001AtgTlsLveErgänzendeDeFehlerMeldungAspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * FG 1 : Typ: 16 Id: 2 Name: Negative Quittung (Antwort) TLS-Datenbeschreibung:<br>
     * <pre>
     * Position         Bezeichnung                             Erläuterung
     * Byte 1           Länge DE-Block                          Länge des folgenden
     * DE-Blocks [ 4 ]
     * Byte 2           Daten-Endgeräte-Kanal                   [ 1..254 ]
     * Byte 3           Typ der DE-Daten                        [ 16 ]
     * Byte 4           Fehlerursache siehe unten
     * Byte 5           Herstellercode                          siehe Liste in
     * Anhang 7, Kap. 2
     * </pre>
     * Inhalt Byte: Fehlerursache unter FG 1:<br>
     * <pre>
     *         0:     sonstige Fehlerursache
     *         1:     unbekannte oder nicht auswertbare ID
     *         2:     unbekannter oder nicht auswertbarer Typ
     *         3:     Version nicht verfügbar
     *     4..11:     reserviert für spätere Definitionen
     *        12:     Pufferinhalt nicht verfügbar
     *   13..127:     reserviert für spätere Definitionen
     *  128..255:     frei für herstellerdefinierte Ursachencodes
     * </pre>
     * Inhalt Byte Herstellercode:<br> Der Herstellercode ist ein für jeden Hersteller eindeutig zugeordneter Code, der der
     * Zentrale die Zuordnung der Nachrichten erleichtern soll.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ016Id002AtgTlsLveNegativeQuittungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return super.Fg255Typ016Id002AtgTlsGloNegativeQuittungAspTlsAntwort(deBlock, data, dataDescription);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ016Id002AtgTlsLveNegativeQuittungAspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ016Id034AtgTlsLveNegativeQuittungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 2, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ016Id002AtgTlsLveNegativeQuittungAspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * FG 1 : Typ: 20 Id: 2 Name: Abruf Pufferinhalt (Abruf) TLS-Datenbeschreibung: Position         Bezeichnung
     * Erläuterung Byte 1           Länge DE-Block Länge des folgenden DE-Blocks [ 7 ] Byte 2 Daten-Endgeräte-Kanal [ 255 ]
     * Byte 3           Typ der DE-Daten [ 20 ] Byte 4           Jahr [ 00..99 ] Byte 5           Monat [ 1..12 ] Byte 6
     * Tag [ 1..31 ] Byte 7 Stunde [ 0/1 *128 + 0..23 ] Byte 8 Anzahl angeforderter Datensätze [ 1..255 ]
     * <p>
     * Inhalt Byte Stunde Bit 0...6:          Angabe der Stunde, binär codiert Bit 7 = 0:          Normalzeit (MEZ) Bit 7 =
     * 1:          Sommerzeit (MESZ)
     * <p>
     * Inhalt Byte Anzahl angeforderter Datensätze: Gibt die Anzahl der zu übertragenden Datensätze an. Dabei wird ab dem
     * durch die Zeitangabe festgelegten Datensatz in Richtung des aktuellen Datensatzes gezählt. Der älteste der
     * geforderten Datensätze wird auch zuerst übertragen.
     *
     * @param result Der vom Datenverteiler empgangene Datensatz, der in einen De-Block konvertiert wird.
     *
     * @return De-Block mit den konvertierten Daten.
     */
    public DeBlock Fg001Typ020Id002AtgTlsLveAbrufPufferInhaltAspTlsAbruf(ResultData result) {
        DeBlock deBlock = null;

        // Datenblock beseht aus folgenden Inhalten:
        int _Jahr_;
        int _Monat_;
        int _Tag_;
        int _Stunde_;
        int _Anzahl_;

        // Umsetzung
        Data              data              = result.getData();  // Datensatz holen
        long              _Zeitpunkt_       = data.getTimeValue("Zeitpunkt").getMillis();
        GregorianCalendar gregorianCalendar = new GregorianCalendar();

        gregorianCalendar.setTimeInMillis(_Zeitpunkt_);
        _Jahr_   = (gregorianCalendar.get(Calendar.YEAR) - 2000);
        _Monat_  = (gregorianCalendar.get(Calendar.MONTH) + 1);
        _Tag_    = (gregorianCalendar.get(Calendar.DAY_OF_MONTH));
        _Stunde_ = (gregorianCalendar.get(Calendar.HOUR_OF_DAY));

        if (gregorianCalendar.get(Calendar.DST_OFFSET) > 0) {
            _Stunde_ += 128;
        }

        debug.finest("Abrufzeit Puffer (" + gregorianCalendar.getTime() + "): " + "Jahr: " + _Jahr_ + " Monat: " + _Monat_ + " Tag: " + _Tag_ + " Stunde: " + _Stunde_);
        _Anzahl_ = data.getUnscaledValue("Anzahl").intValue();

        // DeBlock als TlsData aufbauen...
        TlsData deApplicationData = new TlsData(5);

        deApplicationData.writeIntAsByte(_Jahr_);
        deApplicationData.writeIntAsByte(_Monat_);
        deApplicationData.writeIntAsByte(_Tag_);
        deApplicationData.writeIntAsByte(_Stunde_);
        deApplicationData.writeIntAsByte(_Anzahl_);

        // DeBlock erzeugen
        try {
            deBlock = new DeBlock(deApplicationData, _de.getEak().getSm().getOsi7Adress(), _de.getFg(), 20, 2, _de.getDeChannel());
        }
        catch (IllegalOsi7TelegramStructureException e) {
            debug.warning("Fehler beim Erzeugen eines De-Blocks zum Versand: " + e);
        }

        return deBlock;
    }

    /**
     * FG 1 : Typ: 28 Id: 2 Name: Positive Quittung (Antwort) TLS-Datenbeschreibung:<br>
     * <pre>
     * Position         Bezeichnung                             Erläuterung
     * Byte 1           Länge DE-Block                          Länge des folgenden DE-Blocks [ 2 ]
     * Byte 2           Daten-Endgeräte-Kanal                   [ 1..254 ]
     * Byte 3           Typ der DE-Daten                        [ 28 ]
     * </pre>
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ028Id002AtgTlsLvePositiveQuittungAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Einzeltelegramm, welches die positive Quittung auslöste, ermitteln und speichern
        SingleTelegram singleTelegram      = TlsApplicationLayer.getSendSingleTelegram(_eakConversionModul.getJobNumber());
        String         singleTelegrammText = "Einzeltelegramm, welches die positive Quittung auslöste, konnte nicht ermittelt werden!";

        if (singleTelegram != null) {
            singleTelegrammText = singleTelegram.toString();
        }

        data.getTextValue("EinzelTelegramm").setText(singleTelegrammText);

        // Zuordnung zu versandtem Einzeltelegramm, welches positive Quittung auslöste, ausgeben.
        debug.info("Positive Quittung: \n" + "Versandtes Einzeltelegramm:\n" + singleTelegrammText);

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    /**
     * FG 1 : Typ: 32 Id: 3 Name: LVE-Betriebsparameter (Abruf / Antwort) TLS-Datenbeschreibung:
     * <pre>
     * Position         Bezeichnung                                Erläuterung
     * Byte 1           Länge DE-Block                             Länge des
     * folgenden DE-Blocks [ 10 ]
     * Byte 2           Daten-Endgeräte-Kanal                      [1..254, 255]
     * Byte 3           Typ der DE-Daten                           [ 32 ]
     * Byte 4           Datenversion/Kurzzeitdaten                 [ 0.. 4, 255 =
     * aus ]
     * Byte 5           Erfassungsintervalldauer/Kurzzeitdaten     [
     * 1,2,4,8,12...240, Einheit: 15 s ]
     * Byte 6           Datenversion/Langzeitdaten                 [ 10.. 23, 255 =
     * aus ]
     * Byte 7           Erfassungsintervalldauer/Langzeitdaten     siehe unten
     * Byte 8           Glättungsparameter                         Alpha 1 Alpha 1
     * = (Byteinhalt + 1) / 256
     * Byte 9           Glättungsparameter                         Alpha 2 Alpha 2
     * = (Byteinhalt + 1) / 256
     * Byte 10          Längengrenzwert
     * Lkw/Pkw-Unterscheidung 4m+[0..254cm]
     * Byte 11          Art / Startwert für gl. Mittelwertbildung  siehe unten
     * </pre>
     * Inhalt Byte: Datenversion / Kurzzeitdaten<br> Mit Hilfe dieser Bytes wird die Datenversion ausgewählt, mit der die
     * zyklisch erfassten Verkehrsdaten übertragen werden sollen. Bei Geräten, die die Version 4 nicht unterstützen, wird
     * eine 4 in diesem Byte mit einer negativen Quittung (Fehlerursache 3) beantwortet. Wenn auf die Versionen 4
     * umgeschaltet wird, ohne dass zuvor mit dem DEBlock Typ 37 eine entsprechende Parametrierung der Grenzen der
     * Geschwindigkeitsklassen vorgenommen wurde, dann werden die dort beschriebenen Defaultwerte für die Grenzen der
     * Geschwindigkeitsklassen verwendet.<br>
     * <p>
     * Inhalt Byte: Erfassungsintervalldauer / Kurzzeitdaten:<br> Das Byte enthält den Wert der Erfassungsintervalldauer in
     * 15-Sekunden-Einheiten. Es sind nur Werte zugelassen, die ein ganzzahliges Vielfaches haben, welches 60 Minuten
     * ergibt (15s, 30s, 1, 2, 3, 4, 5, 6, 10, 12, 15, 20, 30, 60 Minuten).
     * <p>
     * Inhalt Byte: Datenversion / Langzeitdaten<br> Mit Hilfe dieser Bytes wird die Datenversion ausgewählt, mit der die
     * zyklisch erfassten Verkehrsdaten übertragen werden sollen. Geräte, von denen eine nicht implementierte Version
     * gefordert wird, antworten mit einer negativen Quittung (Fehlerursache 3). Wenn auf die Versionen 17, 18, 22 oder 23
     * umgeschaltet wird, ohne dass zuvor mit dem DE-Block Typ 38 eine entsprechende Parametrierung der Grenzen der
     * Geschwindigkeitsklassen vorgenommen wurde, dann werden die dort beschriebenen Defaultwerte für die Grenzen der
     * Geschwindigkeitsklassen verwendet.<br>
     * <p>
     * Inhalt Byte: Erfassungsintervalldauer / Langzeitdaten<br> Das Byte enthält den Wert der Erfassungsintervalldauer in
     * Stunden-Einheiten:<br>
     * <pre>
     * Bit7 = 1:    Einheit = Stunden
     * Bit0..6:     Zeitwert in Stunden [1..24]
     * </pre>
     * Es sind nur Stundenwerte zugelassen, die ganzzahlige Teiler oder ganzzahlige Mehrfache von 24 Stunden sind (1, 2, 3,
     * 4, 6, 8, 12, 24 Stunden).<br>
     * <p>
     * Inhalt Byte: Art / Startwert für gleitende Mittelwertbildung:<br> Die gleitende Mittelwertbildung wird nur bei
     * Kurzzeitdaten angewandt. Bei Langzeitdaten wird der arithmetische Mittelwert verwendet.<br>
     * <pre>
     * Bit 0..6:    Startwert der Geschwindigkeit für gleitende Mittelwertbildung
     * [0..127km/h]
     * Bit 7:       Art der Geschwindigkeits-Mittelwertbildung
     *              0=gleitende Mittelwertbildung
     *              1=arithmetische Mittelwertbildung
     * Wichtig:     Bei Auswahl der Version 3 oder 4 müssen immer die
     * Glättungsparameter und Startwerte angegeben werden,
     *              da in diesen Telegrammversionen zusätzlich der gleitende
     * Mittelwert für Steuerungszwecke unabhängig
     *              von der Einstellung in Bit 7 übertragen wird.
     * </pre>
     * Inhalt Byte: Längengrenzwert<br> Bei E/A-Konzentratoren ohne Längenauswertung wird bei der Zuweisung das Byte
     * ignoriert. In der Antwort dieses E/A-Konzentrators wird es auf 255 gesetzt.<br>
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ032Id003AtgTlsLveBetriebsParameterAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // VersionKurz-Byte aus Telegramm ------------------------------------------------------------------------------
        int _VersionKurz_ = deBlock.getDeData().readUnsignedByteAsInt();

        switch (_VersionKurz_) {
        case 0 :
        case 1 :
        case 2 :
        case 3 :
        case 4 :
        case 255 :
            data.getUnscaledValue("VersionKurzZeitDaten").set(_VersionKurz_);

            break;

        default :
            debug.warning("VersionKurzZeitDaten ungültig : " + _VersionKurz_ + Debug.NEWLINE + "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE + deBlock.toString());

            return resultData;
        }

        // Intervalldaten Kurzzeit-Byte aus Telegramm ------------------------------------------------------------------
        int _IntervallKurz_ = deBlock.getDeData().readUnsignedByteAsInt();

        switch (_IntervallKurz_) {
        case 1 :
        case 2 :
        case 4 :
        case 8 :
        case 12 :
        case 16 :
        case 20 :
        case 24 :
        case 40 :
        case 48 :
        case 60 :
        case 80 :
        case 120 :
        case 240 :
            data.getUnscaledValue("IntervallDauerKurzZeitDaten").set(_IntervallKurz_);

            break;

        default :
            debug.warning("IntervallDauerKurzZeitDaten ungültig : " + _IntervallKurz_ + Debug.NEWLINE + "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE + deBlock.toString());

            return resultData;
        }

        // VersionLang-Byte aus Telegramm ------------------------------------------------------------------------------
        int _VersionLang_ = deBlock.getDeData().readUnsignedByteAsInt();

        switch (_VersionLang_) {
        case 10 :
        case 11 :
        case 12 :
        case 13 :
        case 14 :
        case 15 :
        case 16 :
        case 17 :
        case 18 :
        case 19 :
        case 20 :
        case 21 :
        case 22 :
        case 23 :
        case 24 :
        case 255 :
            data.getUnscaledValue("VersionLangZeitDaten").set(_VersionLang_);

            break;

        default :
            debug.warning("VersionLangZeitDaten ungültig : " + _VersionLang_ + Debug.NEWLINE + "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE + deBlock.toString());

            return resultData;
        }

        // Întervalldaten Langzeit-Byte aus Telegramm ------------------------------------------------------------------
        int _IntervallLang_ = deBlock.getDeData().readUnsignedByteAsInt();

        switch (_IntervallLang_) {
        case 129 :
        case 130 :
        case 131 :
        case 132 :
        case 134 :
        case 136 :
        case 140 :
        case 152 :
            data.getUnscaledValue("IntervallDauerLangZeit").set(_IntervallLang_);

            break;

        default :
            debug.warning("IntervallDauerLangZeit ungültig : " + _IntervallLang_ + Debug.NEWLINE + "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE + deBlock.toString());

            return resultData;
        }

        // Alpha 1-Byte aus Telegramm ----------------------------------------------------------------------------------
        int _alpha1_ = deBlock.getDeData().readUnsignedByteAsInt();

        data.getUnscaledValue("alpha1").set(_alpha1_ + 1);

        // Alpha 2-Byte aus Telegramm ----------------------------------------------------------------------------------
        int _alpha2_ = deBlock.getDeData().readUnsignedByteAsInt();

        data.getUnscaledValue("alpha2").set(_alpha2_ + 1);

        // Längengrenzwert für LKW-Byte aus Telegramm ------------------------------------------------------------------
        int _LaengeLKW_ = deBlock.getDeData().readUnsignedByteAsInt();

        if (_LaengeLKW_ == 255) {
            data.getUnscaledValue("LängenGrenzWert").setText("kein Längengrenzwert");
        } else {
            data.getUnscaledValue("LängenGrenzWert").set(_LaengeLKW_ + 400);
        }

        // Startwert für Mittelwertbilung-Byte aus Telegramm -----------------------------------------------------------
        int _MittelWert_        = deBlock.getDeData().readUnsignedByteAsInt();
        int _MittelWertBildung_ = _MittelWert_ & 0x80;
        int _MittelWertStart_   = _MittelWert_ & 0x7f;

        if (_MittelWertBildung_ == 0) {
            data.getUnscaledValue("ArtMittelWertBildung").setText("gleitende Mittelwertbildung");
            _kindOfAverage = 0;
        } else {
            data.getUnscaledValue("ArtMittelWertBildung").setText("arithmetische Mittelwertbildung");
            _kindOfAverage = 1;
        }

        data.getUnscaledValue("StartMittelWertBildung").set(_MittelWertStart_);

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    /**
     * FG 1 : Typ: 32 Id: 3 Name: LVE-Betriebsparameter (Abruf / Antwort) TLS-Datenbeschreibung:
     * <pre>
     * Position         Bezeichnung                                Erläuterung
     * Byte 1           Länge DE-Block                             Länge des
     * folgenden DE-Blocks [ 10 ]
     * Byte 2           Daten-Endgeräte-Kanal                      [1..254, 255]
     * Byte 3           Typ der DE-Daten                           [ 32 ]
     * Byte 4           Datenversion/Kurzzeitdaten                 [ 0.. 4, 255 =
     * aus ]
     * Byte 5           Erfassungsintervalldauer/Kurzzeitdaten     [
     * 1,2,4,8,12...240, Einheit: 15 s ]
     * Byte 6           Datenversion/Langzeitdaten                 [ 10.. 23, 255 =
     * aus ]
     * Byte 7           Erfassungsintervalldauer/Langzeitdaten     siehe unten
     * Byte 8           Glättungsparameter                         Alpha 1 Alpha 1
     * = (Byteinhalt + 1) / 256
     * Byte 9           Glättungsparameter                         Alpha 2 Alpha 2
     * = (Byteinhalt + 1) / 256
     * Byte 10          Längengrenzwert
     * Lkw/Pkw-Unterscheidung 4m+[0..254cm]
     * Byte 11          Art / Startwert für gl. Mittelwertbildung  siehe unten
     * </pre>
     * Inhalt Byte: Datenversion / Kurzzeitdaten<br> Mit Hilfe dieser Bytes wird die Datenversion ausgewählt, mit der die
     * zyklisch erfassten Verkehrsdaten übertragen werden sollen. Bei Geräten, die die Version 4 nicht unterstützen, wird
     * eine 4 in diesem Byte mit einer negativen Quittung (Fehlerursache 3) beantwortet. Wenn auf die Versionen 4
     * umgeschaltet wird, ohne dass zuvor mit dem DEBlock Typ 37 eine entsprechende Parametrierung der Grenzen der
     * Geschwindigkeitsklassen vorgenommen wurde, dann werden die dort beschriebenen Defaultwerte für die Grenzen der
     * Geschwindigkeitsklassen verwendet.<br>
     * <p>
     * Inhalt Byte: Erfassungsintervalldauer / Kurzzeitdaten:<br> Das Byte enthält den Wert der Erfassungsintervalldauer in
     * 15-Sekunden-Einheiten. Es sind nur Werte zugelassen, die ein ganzzahliges Vielfaches haben, welches 60 Minuten
     * ergibt (15s, 30s, 1, 2, 3, 4, 5, 6, 10, 12, 15, 20, 30, 60 Minuten).
     * <p>
     * Inhalt Byte: Datenversion / Langzeitdaten<br> Mit Hilfe dieser Bytes wird die Datenversion ausgewählt, mit der die
     * zyklisch erfassten Verkehrsdaten übertragen werden sollen. Geräte, von denen eine nicht implementierte Version
     * gefordert wird, antworten mit einer negativen Quittung (Fehlerursache 3). Wenn auf die Versionen 17, 18, 22 oder 23
     * umgeschaltet wird, ohne dass zuvor mit dem DE-Block Typ 38 eine entsprechende Parametrierung der Grenzen der
     * Geschwindigkeitsklassen vorgenommen wurde, dann werden die dort beschriebenen Defaultwerte für die Grenzen der
     * Geschwindigkeitsklassen verwendet.<br>
     * <p>
     * Inhalt Byte: Erfassungsintervalldauer / Langzeitdaten<br> Das Byte enthält den Wert der Erfassungsintervalldauer in
     * Stunden-Einheiten:<br>
     * <pre>
     * Bit7 = 1:    Einheit = Stunden
     * Bit0..6:     Zeitwert in Stunden [1..24]
     * </pre>
     * Es sind nur Stundenwerte zugelassen, die ganzzahlige Teiler oder ganzzahlige Mehrfache von 24 Stunden sind (1, 2, 3,
     * 4, 6, 8, 12, 24 Stunden).<br>
     * <p>
     * Inhalt Byte: Art / Startwert für gleitende Mittelwertbildung:<br> Die gleitende Mittelwertbildung wird nur bei
     * Kurzzeitdaten angewandt. Bei Langzeitdaten wird der arithmetische Mittelwert verwendet.<br>
     * <pre>
     * Bit 0..6:    Startwert der Geschwindigkeit für gleitende Mittelwertbildung
     * [0..127km/h]
     * Bit 7:       Art der Geschwindigkeits-Mittelwertbildung
     *              0=gleitende Mittelwertbildung
     *              1=arithmetische Mittelwertbildung
     * Wichtig:     Bei Auswahl der Version 3 oder 4 müssen immer die
     * Glättungsparameter und Startwerte angegeben werden,
     *              da in diesen Telegrammversionen zusätzlich der gleitende
     * Mittelwert für Steuerungszwecke unabhängig
     *              von der Einstellung in Bit 7 übertragen wird.
     * </pre>
     * Inhalt Byte: Längengrenzwert<br> Bei E/A-Konzentratoren ohne Längenauswertung wird bei der Zuweisung das Byte
     * ignoriert. In der Antwort dieses E/A-Konzentrators wird es auf 255 gesetzt.<br>
     *
     * @param result Der vom Datenverteiler empgangene Datensatz, der in einen De-Block konvertiert wird.
     *
     * @return De-Block mit den konvertierten Daten.
     */
    public DeBlock Fg001Typ032Id003AtgTlsLveBetriebsParameterAspParameterSoll(ResultData result) {
        DeBlock deBlock = null;

        // Datenblock beseht aus folgenden Inhalten:
        int _VersionKurz_;
        int _IntervallKurz_;
        int _VersionLang_;
        int _IntervallLang_;
        int _alpha1_;
        int _alpha2_;
        int _LaengeLKW_;
        int _MittelWert_;

        // Hilfvariablen
        int _MittelWertBildung_;
        int _MittelWertStart_;

        // Umsetzung
        Data data = result.getData();  // Datensatz holen

        _VersionKurz_   = data.getUnscaledValue("VersionKurzZeitDaten").intValue();
        _IntervallKurz_ = data.getUnscaledValue("IntervallDauerKurzZeitDaten").intValue();
        _VersionLang_   = data.getUnscaledValue("VersionLangZeitDaten").intValue();
        _IntervallLang_ = data.getUnscaledValue("IntervallDauerLangZeit").intValue();
        _alpha1_        = data.getUnscaledValue("alpha1").intValue() - 1;
        _alpha2_        = data.getUnscaledValue("alpha2").intValue() - 1;
        _LaengeLKW_     = data.getUnscaledValue("LängenGrenzWert").intValue();

        if (_LaengeLKW_ != 255) {
            _LaengeLKW_ -= 400;
        }

        _MittelWertBildung_ = data.getUnscaledValue("ArtMittelWertBildung").intValue();
        _kindOfAverage      = _MittelWertBildung_;
        _MittelWertStart_   = data.getUnscaledValue("StartMittelWertBildung").intValue();
        _MittelWert_        = _MittelWertStart_ + (_MittelWertBildung_ << 7);

        // DeBlock als TlsData aufbauen...
        TlsData deApplicationData = new TlsData(8);

        deApplicationData.writeIntAsByte(_VersionKurz_);
        deApplicationData.writeIntAsByte(_IntervallKurz_);
        deApplicationData.writeIntAsByte(_VersionLang_);
        deApplicationData.writeIntAsByte(_IntervallLang_);
        deApplicationData.writeIntAsByte(_alpha1_);
        deApplicationData.writeIntAsByte(_alpha2_);
        deApplicationData.writeIntAsByte(_LaengeLKW_);
        deApplicationData.writeIntAsByte(_MittelWert_);

        // DeBlock erzeugen
        try {
            deBlock = new DeBlock(deApplicationData, _de.getEak().getSm().getOsi7Adress(), _de.getFg(), 32, 3, _de.getDeChannel());
        }
        catch (IllegalOsi7TelegramStructureException e) {
            debug.warning("Fehler beim Erzeugen eines De-Blocks zum Versand: " + e);
        }

        return deBlock;
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ032Id003AtgTlsLveBetriebsParameterAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ032Id035AtgTlsLveBetriebsParameterAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ032Id003AtgTlsLveBetriebsParameterAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * FG 1 : Typ: 34 Id: 3 Name: SVE-Betriebsparameter (Abruf / Antwort) TLS-Datenbeschreibung:
     * <pre>
     * Position         Bezeichnung                             Erläuterung
     * Byte 1           Länge DE-Block                          Länge des folgenden
     * DE-Blocks [ 4 ]
     * Byte 2           Daten-Endgeräte-Kanal                   [ 1..254, 255]
     * Byte 3           Typ der DE-Daten                        [ 34 ]
     * Byte 4           Datenversion                            [ 0,1; 255 = aus ]
     * Byte 5           Erfassungsintervalldauer                [1, 2, 4, 8,
     * Einheit 15 s ]
     * </pre>
     * Inhalt Byte Datenversion:<br> Die Datenversion bezieht sich auf die SVE-Ergebnismeldung Version 0 (Standard) [0]
     * bzw. Version 1 [1]. Mit dem Wert 255 lässt sich die streckenbezogene Verkehrsdatenerfassung abschalten. <br> Inhalt
     * Byte Erfassungsintervalldauer:<br> Die Erfassungsintervalldauer wird in folgenden Vielfachen von 15 sec kodiert: 15s
     * [1], 30s [2], 60s [4] und 120s [8]. Eine Erfassungsintervalldauer größer als 2 Minuten erscheint aufgrund des
     * technischen Verfahrens nicht sinnvoll und sollte zentralenseitig durch Mittelwertbildung gewonnen werden.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ034Id003AtgTlsSveBetriebsParameterAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Version-Byte aus Telegramm ------------------------------------------------------------------------------
        int _Version_ = deBlock.getDeData().readUnsignedByteAsInt();

        switch (_Version_) {
        case 0 :
        case 1 :
        case 255 :
            data.getUnscaledValue("Version").set(_Version_);

            break;

        default :
            debug.warning("Version ungültig : " + _Version_ + Debug.NEWLINE + "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE + deBlock.toString());

            return resultData;
        }

        // IntervallDauer-Byte aus Telegramm ------------------------------------------------------------------
        int _IntervallDauer_ = deBlock.getDeData().readUnsignedByteAsInt();

        switch (_IntervallDauer_) {
        case 1 :
        case 2 :
        case 4 :
        case 8 :
            data.getUnscaledValue("IntervallDauer").set(_IntervallDauer_);

            break;

        default :
            debug.warning("IntervallDauer ungültig : " + _IntervallDauer_ + Debug.NEWLINE + "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE + deBlock.toString());

            return resultData;
        }

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    /**
     * FG 1 : Typ: 34 Id: 3 Name: SVE-Betriebsparameter (Abruf / Antwort) TLS-Datenbeschreibung:
     * <pre>
     * Position         Bezeichnung                             Erläuterung
     * Byte 1           Länge DE-Block                          Länge des folgenden
     * DE-Blocks [ 4 ]
     * Byte 2           Daten-Endgeräte-Kanal                   [ 1..254, 255]
     * Byte 3           Typ der DE-Daten                        [ 34 ]
     * Byte 4           Datenversion                            [ 0,1; 255 = aus ]
     * Byte 5           Erfassungsintervalldauer                [1, 2, 4, 8,
     * Einheit 15 s ]
     * </pre>
     * Inhalt Byte Datenversion:<br> Die Datenversion bezieht sich auf die SVE-Ergebnismeldung Version 0 (Standard) [0]
     * bzw. Version 1 [1]. Mit dem Wert 255 lässt sich die streckenbezogene Verkehrsdatenerfassung abschalten. <br> Inhalt
     * Byte Erfassungsintervalldauer:<br> Die Erfassungsintervalldauer wird in folgenden Vielfachen von 15 sec kodiert: 15s
     * [1], 30s [2], 60s [4] und 120s [8]. Eine Erfassungsintervalldauer größer als 2 Minuten erscheint aufgrund des
     * technischen Verfahrens nicht sinnvoll und sollte zentralenseitig durch Mittelwertbildung gewonnen werden.
     *
     * @param result Der vom Datenverteiler empgangene Datensatz, der in einen De-Block konvertiert wird.
     *
     * @return De-Block mit den konvertierten Daten.
     */
    public DeBlock Fg001Typ034Id003AtgTlsSveBetriebsParameterAspParameterSoll(ResultData result) {
        DeBlock deBlock = null;

        // Datenblock beseht aus folgenden Inhalten:
        int _Version_;
        int _IntervallDauer_;

        // Umsetzung
        Data data = result.getData();  // Datensatz holen

        _Version_        = data.getUnscaledValue("Version").intValue();
        _IntervallDauer_ = data.getUnscaledValue("IntervallDauer").intValue();

        // DeBlock als TlsData aufbauen...
        TlsData deApplicationData = new TlsData(2);

        deApplicationData.writeIntAsByte(_Version_);
        deApplicationData.writeIntAsByte(_IntervallDauer_);

        // DeBlock erzeugen
        try {
            deBlock = new DeBlock(deApplicationData, _de.getEak().getSm().getOsi7Adress(), _de.getFg(), 34, 3, _de.getDeChannel());
            debug.finest("TLS-DE-Block: " + HexDumper.toString(deBlock.getTlsDeDataBlock()));
        }
        catch (IllegalOsi7TelegramStructureException e) {
            debug.warning("Fehler beim Erzeugen eines De-Blocks zum Versand: " + e);
        }

        return deBlock;
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ034Id003AtgTlsSveBetriebsParameterAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ034Id035AtgTlsSveBetriebsParameterAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ034Id003AtgTlsSveBetriebsParameterAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    private DeBlock Fg001Typ037Bis038Id003BuildDeBlock(ResultData result, int FZKlasse, int typ) {
        DeBlock deBlock = null;

        // Datenblock beseht aus folgenden Inhalten:
        int _FZKlasse_ = FZKlasse;
        int _vGrenz_;

        // Umsetzung
        Data data  = result.getData();  // Datensatz holen
        int  count = data.getArray("vGrenz").getLength();

        // DeBlock als TlsData aufbauen...
        TlsData deApplicationData = new TlsData(2 + count);

        deApplicationData.writeIntAsByte(_FZKlasse_);
        deApplicationData.writeIntAsByte(count);

        for (int i = 0; i < count; i++) {
            _vGrenz_ = data.getUnscaledArray("vGrenz").getValue(i).intValue();
            deApplicationData.writeIntAsByte(_vGrenz_);
        }

        // DeBlock erzeugen
        try {
            deBlock = new DeBlock(deApplicationData, _de.getEak().getSm().getOsi7Adress(), _de.getFg(), typ, 3, _de.getDeChannel());
            debug.finest("TLS-DE-Block: " + HexDumper.toString(deBlock.getTlsDeDataBlock()));
        }
        catch (IllegalOsi7TelegramStructureException e) {
            debug.warning("Fehler beim Erzeugen eines De-Blocks zum Versand: " + e);
        }

        return deBlock;
    }

    /**
     * FG 1 : Typ: 38 Id: 3 Name: Parameter für Geschwindigkeitsklassen bei Langzeitdaten (Abruf / Antwort)
     * TLS-Datenbeschreibung: Position Bezeichnung                             Erläuterung Byte 1           Länge DE-Block
     * Länge des folgenden DE-Blocks Byte 2 Daten-Endgeräte-Kanal [1..254, 255] Byte 3 Typ der DE-Daten [ 38 ] Byte 4
     * Fahrzeugklassen-Code                    [ siehe unten] Byte 5           Anzahl der Klassengrenzen [ 0,1..15 ] Byte 6
     *           Grenze der 1. Geschw.-Klasse            [ 5..254 km/h] ..... ..... Byte ... Grenze der n-1.-Geschw.-Klasse
     * [ 5..254 km/h]
     * <p/>
     * Inhalt Byte: Fahrzeugklassen-Code Die einzelnen Geschwindigkeitsklassengrenzen können je Fahrzeugklasse
     * unterschiedlich definiert werden. Für die Datenversionen 17 und 22 werden die Geschwindigkeitsklassen für die
     * Fahrzeugklasse Pkw-Ähnliche (Fahrzeugklassen-Code 32) und die Fahrzeugklasse Lkw-Ähnliche (Fahrzeugklassen-Code 33)
     * übertragen.
     * <p/>
     * Für die Datenversion 18 werden die Geschwindigkeitsklassen für bis zu 5 Fahrzeugklassen gemäß Anhang 2, Kapitel 2
     * übertragen. Für die Datenversion 23 werden die Geschwindigkeitsklassen für bis zu 8 Fahrzeugklassen gemäß Anhang 2,
     * Kapitel 2 übertragen.
     * <p/>
     * Inhalt Byte: Anzahl Geschwindigkeitsklassengrenzen entspricht der Festlegung bei Typ 37
     * <p/>
     * Inhalt Bytes: Grenzen der Geschwindigkeitsklassen entspricht der Festlegung bei Typ 37
     * <p/>
     * Für Messstellen, an denen Geschwindigkeitsklassen für statistische Zwecke (ausgewählte Dauerzählstellen des Bundes)
     * erfasst werden, wird folgende Konfiguration für die Version 17 verwendet:
     * <p/>
     * 15 Grenzen für Pkw-Ähnliche:        20, 30, 40, 50, 60, 70, 80, 90, 100, 110, 120, 130, 140, 150 und 170 km/h 11
     * Grenzen für die Lkw-Ähnliche:    20, 30, 40, 50, 60, 70, 80, 90, 100, 110 und 120 km/h
     * <p/>
     * Diese Grenzen gelten außerdem in jedem Fall als Defaultwerte, solange sie nicht mit einem DE-Block Typ 38
     * überschrieben worden sind.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     * @param FZKlasse        Zu berücksichtigende Fahrzeugklasse.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    private ResultData Fg001Typ037Bis038Id003ProcessDeBlock(DeBlock deBlock, Data data, DataDescription dataDescription, int FZKlasse) {

        // FZKlasse-Byte aus Telegramm ---------------------------------------------------------------------------------
        deBlock.getDeData().rewindReadPosition();

        int _FZKlasse_ = deBlock.getDeData().readUnsignedByteAsInt();

        if (_FZKlasse_ == FZKlasse) {

            // Grenzgeschwindigkeiten aus Telegramm -------------------------------------------------------------------------
            int _vGrenz_;
            int count = deBlock.getDeData().readUnsignedByteAsInt();  // Anzahl der Geschwindigkeitsgrenzen

            // vGrenz kann Länge 0, 1 ... 15 haben
            data.getArray("vGrenz").setLength(count);

            // Parameter merken
            int _vGrenzXXX[] = new int[count];

            for (int i = 0; i < count; i++) {
                _vGrenz_      = deBlock.getDeData().readUnsignedByteAsInt();
                _vGrenzXXX[i] = _vGrenz_;
                data.getUnscaledArray("vGrenz").getValue(i).set(_vGrenz_);
            }

            switch (FZKlasse) {
            case 36 :
                _vGrenzLVo = _vGrenzXXX;

                break;

            case 34 :
                _vGrenzSGV = _vGrenzXXX;

                break;

            case 35 :
                _vGrenzBPA = _vGrenzXXX;

                break;
            }
        } else {
            return null;  // TBD: Spezielle Behandlung: Keinen Datensatz versenden, da diese Methode n-fach aufgerufen wird,

            // aber nur einmal mit dem korrekten Typ !!
        }

        // Ergebnisdatensatz erzeugen...
        ResultData resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    public ResultData Fg001Typ037Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenLkwÄAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 33);
    }

    public DeBlock Fg001Typ037Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenLkwÄAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 33, 37);
    }

    /**
     * FG 1 : Typ: 37 Id: 3 Name: Parameter für Geschwindigkeitsklassen bei Kurzzeitdaten (Abruf / Antwort)
     * TLS-Datenbeschreibung:
     * <pre>
     * Position         Bezeichnung                             Erläuterung
     * Byte 1           Lange DE-Block                          Lange des folgenden
     * DE-Blocks
     * Byte 2           Daten-Endgerate-Kanal                   [1..254, 255]
     * Byte 3           Typ der DE-Daten                        [ 37 ]
     * Byte 4           Fahrzeugklassen-Code                    [ siehe unten]
     * Byte 5           Anzahl der Geschwin.-Klassengrenzen     [ 0, 1..15 ]
     * Byte 6           Grenze der 1. Geschwin.-Klasse          [5..254 km/h]
     * ..... .....
     * Byte ...         Grenze der n-1.-Geschw.-Klasse          [5..254 km/h]
     * </pre>
     * Inhalt Byte: Fahrzeugklassen-Code<br> Die einzelnen Geschwindigkeitsklassengrenzen konnen je Fahrzeugklasse
     * unterschiedlich definiert werden. <br> Deshalb muss in diesem Byte die Fahrzeugklasse, auf die sich die Festlegungen
     * beziehen angegeben werden. Es werden die Geschwindigkeitsklassen fur die Fahrzeugklasse "Pkw-ahnliche"
     * (Fahrzeugklassen-Code 32) und die Fahrzeugklasse "Lkw-ahnliche" (Fahrzeugklassen-Code 33) ubertragen. <br> Inhalt
     * Byte: Anzahl Geschwindigkeitsklassengrenzen<br> In diesem Byte wird die Anzahl der folgenden Grenzen angegeben. Sie
     * liegt im Bereich von 1..15. Sie ist um eins niedriger als die Anzahl der Geschwindigkeitsklassen. Werden fur eine
     * Fahrzeugklasse keine Werte benotigt, so ist die Anzahl der Grenzen auf 0 zu setzen. <br> Inhalt Bytes: Grenze der
     * Geschwindigkeitsklasse<br> Mit Hilfe dieser Bytes werden die Grenzen einer Geschwindigkeitsklasse festgelegt.
     * Folgende Regeln mussen dabei eingehalten werden:
     * <pre>
     * 1. Es gilt fur alle Klassen untere Grenze &lt; Wert &lt;_ obere Grenze.
     * 2. Die Reihenfolge der Klassen im DE-Block ist immer von der kleinsten
     * Geschwindigkeitsklasse zur gro©¬ten.
     * 3. Die unterste Grenze der ersten Klasse ist immer 0 km/h.
     * 4. Die letzte Klasse ist immer nach oben unbegrenzt.
     * 5. Die DE-Block-Struktur muss immer alle Grenzen fur eine Fahrzeugklasse
     * enthalten, da die alten Grenzen bei
     *    Neudefinition vollstandig gelöscht werden.
     * 6. Die neu ubermittelten Grenzen werden ab dem nachsten Messintervall
     * angewandt. Das gerade aktuelle Intervall
     *    wird verworfen. Um Ubergangsprobleme zu vermeiden, sollten die DE-Blocke
     * fur Fahrzeugklassen, bei
     *    denen sich Grenzen andern, in einem Telegramm ubermitteln werden.
     * </pre>
     * Fur Sondermessstellen, an denen innerhalb von Verkehrsbeeinflussungsanlagen Geschwindigkeitsklassen erfasst werden,
     * wird folgende Konfiguration verwendet: <br> 15 Klassengrenzen fur Pkw-ahnliche:  20, 30, 40, 50, 60, 70, 80, 90,
     * 100, 110, 120, 130, 140, 150 und 170 km/h<br> 11 Grenzen fur die Lkw-ahnliche:     20, 30, 40, 50, 60, 70, 80, 90,
     * 100, 110 und 120 km/h<br> Diese Grenzen gelten ausserdem in jedem Fall als Defaultwerte, solange sie nicht mit einem
     * DE-Block Typ 37 ueberschrieben worden sind.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ037Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenPkwÄAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 32);
    }

    /**
     * FG 1 : Typ: 37 Id: 3 Name: Parameter für Geschwindigkeitsklassen bei Kurzzeitdaten (Abruf / Antwort)
     * TLS-Datenbeschreibung:
     * <pre>
     * Position         Bezeichnung                             Erläuterung
     * Byte 1           Lange DE-Block                          Lange des folgenden
     * DE-Blocks
     * Byte 2           Daten-Endgerate-Kanal                   [1..254, 255]
     * Byte 3           Typ der DE-Daten                        [ 37 ]
     * Byte 4           Fahrzeugklassen-Code                    [ siehe unten]
     * Byte 5           Anzahl der Geschwin.-Klassengrenzen     [ 0, 1..15 ]
     * Byte 6           Grenze der 1. Geschwin.-Klasse          [5..254 km/h]
     * ..... .....
     * Byte ...         Grenze der n-1.-Geschw.-Klasse          [5..254 km/h]
     * </pre>
     * Inhalt Byte: Fahrzeugklassen-Code<br> Die einzelnen Geschwindigkeitsklassengrenzen konnen je Fahrzeugklasse
     * unterschiedlich definiert werden. <br> Deshalb muss in diesem Byte die Fahrzeugklasse, auf die sich die Festlegungen
     * beziehen angegeben werden. Es werden die Geschwindigkeitsklassen fur die Fahrzeugklasse "Pkw-ahnliche"
     * (Fahrzeugklassen-Code 32) und die Fahrzeugklasse "Lkw-ahnliche" (Fahrzeugklassen-Code 33) ubertragen. <br> Inhalt
     * Byte: Anzahl Geschwindigkeitsklassengrenzen<br> In diesem Byte wird die Anzahl der folgenden Grenzen angegeben. Sie
     * liegt im Bereich von 1..15. Sie ist um eins niedriger als die Anzahl der Geschwindigkeitsklassen. Werden fur eine
     * Fahrzeugklasse keine Werte benotigt, so ist die Anzahl der Grenzen auf 0 zu setzen. <br> Inhalt Bytes: Grenze der
     * Geschwindigkeitsklasse<br> Mit Hilfe dieser Bytes werden die Grenzen einer Geschwindigkeitsklasse festgelegt.
     * Folgende Regeln mussen dabei eingehalten werden:
     * <pre>
     * 1. Es gilt fur alle Klassen untere Grenze &lt; Wert &lt;_ obere Grenze.
     * 2. Die Reihenfolge der Klassen im DE-Block ist immer von der kleinsten
     * Geschwindigkeitsklasse zur gro©¬ten.
     * 3. Die unterste Grenze der ersten Klasse ist immer 0 km/h.
     * 4. Die letzte Klasse ist immer nach oben unbegrenzt.
     * 5. Die DE-Block-Struktur muss immer alle Grenzen fur eine Fahrzeugklasse
     * enthalten, da die alten Grenzen bei
     *    Neudefinition vollstandig gelöscht werden.
     * 6. Die neu ubermittelten Grenzen werden ab dem nachsten Messintervall
     * angewandt. Das gerade aktuelle Intervall
     *    wird verworfen. Um Ubergangsprobleme zu vermeiden, sollten die DE-Blocke
     * fur Fahrzeugklassen, bei
     *    denen sich Grenzen andern, in einem Telegramm ubermitteln werden.
     * </pre>
     * Fur Sondermessstellen, an denen innerhalb von Verkehrsbeeinflussungsanlagen Geschwindigkeitsklassen erfasst werden,
     * wird folgende Konfiguration verwendet: <br> 15 Klassengrenzen fur Pkw-ahnliche:  20, 30, 40, 50, 60, 70, 80, 90,
     * 100, 110, 120, 130, 140, 150 und 170 km/h<br> 11 Grenzen fur die Lkw-ahnliche:     20, 30, 40, 50, 60, 70, 80, 90,
     * 100, 110 und 120 km/h<br> Diese Grenzen gelten ausserdem in jedem Fall als Defaultwerte, solange sie nicht mit einem
     * DE-Block Typ 37 ueberschrieben worden sind.
     *
     * @param result Der vom Datenverteiler empgangene Datensatz, der in einen De-Block konvertiert wird.
     *
     * @return De-Block mit den konvertierten Daten.
     */
    public DeBlock Fg001Typ037Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenPkwÄAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 32, 37);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ037Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenLkwÄAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ037Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenLkwÄAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ037Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenLkwÄAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ037Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenPkwÄAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ037Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenPkwÄAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ037Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiKurzzeitDatenPkwÄAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBPAAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 35);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBPAAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 35, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBusAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 5);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBusAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 5, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 64);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 64, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzNkAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 6);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzNkAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 6, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKradAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 10);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKradAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 10, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLfwAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 11);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLfwAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 11, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwAAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 8);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwAAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 8, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 3);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 3, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwKAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 4);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwKAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 4, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwÄAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 33);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwÄAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 33, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLVoAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 36);
    }

    // ----------------------------------------------------------------------
    // Erweiterte Parametrierungen für Datenversion 24 (LVE-Param.+V-Klassen)
    // ----------------------------------------------------------------------
    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLVoAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 36, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwAAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 2);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwAAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 2, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 7);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 7, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwGAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 1);
    }

    /**
     * FG 1 : Typ: 38 Id: 3 Name: Parameter für Geschwindigkeitsklassen bei Langzeitdaten (Abruf / Antwort)
     * TLS-Datenbeschreibung: Position Bezeichnung                             Erläuterung Byte 1           Länge DE-Block
     * Länge des folgenden DE-Blocks Byte 2 Daten-Endgeräte-Kanal [1..254, 255] Byte 3 Typ der DE-Daten [ 38 ] Byte 4
     * Fahrzeugklassen-Code                    [ siehe unten] Byte 5           Anzahl der Klassengrenzen [ 0,1..15 ] Byte 6
     *           Grenze der 1. Geschw.-Klasse            [ 5..254 km/h] ..... ..... Byte ... Grenze der n-1.-Geschw.-Klasse
     * [ 5..254 km/h]
     * <p>
     * Inhalt Byte: Fahrzeugklassen-Code Die einzelnen Geschwindigkeitsklassengrenzen können je Fahrzeugklasse
     * unterschiedlich definiert werden. Für die Datenversionen 17 und 22 werden die Geschwindigkeitsklassen für die
     * Fahrzeugklasse Pkw-Ähnliche (Fahrzeugklassen-Code 32) und die Fahrzeugklasse Lkw-Ähnliche (Fahrzeugklassen-Code 33)
     * übertragen.
     * <p>
     * Für die Datenversion 18 werden die Geschwindigkeitsklassen für bis zu 5 Fahrzeugklassen gemäß Anhang 2, Kapitel 2
     * übertragen. Für die Datenversion 23 werden die Geschwindigkeitsklassen für bis zu 8 Fahrzeugklassen gemäß Anhang 2,
     * Kapitel 2 übertragen.
     * <p>
     * Inhalt Byte: Anzahl Geschwindigkeitsklassengrenzen entspricht der Festlegung bei Typ 37
     * <p>
     * Inhalt Bytes: Grenzen der Geschwindigkeitsklassen entspricht der Festlegung bei Typ 37
     * <p>
     * Für Messstellen, an denen Geschwindigkeitsklassen für statistische Zwecke (ausgewählte Dauerzählstellen des Bundes)
     * erfasst werden, wird folgende Konfiguration für die Version 17 verwendet:
     * <p>
     * 15 Grenzen für Pkw-Ähnliche:        20, 30, 40, 50, 60, 70, 80, 90, 100, 110, 120, 130, 140, 150 und 170 km/h 11
     * Grenzen für die Lkw-Ähnliche:    20, 30, 40, 50, 60, 70, 80, 90, 100, 110 und 120 km/h
     * <p>
     * Diese Grenzen gelten außerdem in jedem Fall als Defaultwerte, solange sie nicht mit einem DE-Block Typ 38
     * überschrieben worden sind.
     *
     * @param result Der vom Datenverteiler empgangene Datensatz, der in einen De-Block konvertiert wird.
     *
     * @return De-Block mit den konvertierten Daten.
     */
    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwGAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 1, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwÄAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 32);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwÄAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 32, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSattelKfzAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 9);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSattelKfzAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 9, 38);
    }

    public ResultData Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSGVAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return Fg001Typ037Bis038Id003ProcessDeBlock(deBlock, data, dataDescription, 34);
    }

    public DeBlock Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSGVAspParameterSoll(ResultData result) {
        return Fg001Typ037Bis038Id003BuildDeBlock(result, 34, 38);
    }

    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBPAAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBPAAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBusAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBusAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenBusAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzNkAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzNkAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKfzNkAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKradAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKradAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenKradAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLfwAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLfwAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLfwAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwAAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwAAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwAAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwKAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwKAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwKAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwÄAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwÄAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLkwÄAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLVoAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenLVoAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwAAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwAAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwAAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwGAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwGAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwGAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwÄAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwÄAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenPkwÄAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSattelKfzAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSattelKfzAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSattelKfzAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ038Id035AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSGVAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ038Id003AtgTlsLveParameterFürGeschwindigkeitsKlassenBeiLangzeitDatenSGVAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ049Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ049Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ049Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ049Id036AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ049Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ049Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ049Id036AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ049Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ050Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ050Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ050Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ050Id036AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ050Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ050Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ050Id036AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ050Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ051Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ051Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ051Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ051Id036AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ051Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ051Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ051Id036AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ051Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ052Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ052Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ052Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ052Id036AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ052Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ052Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ052Id036AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ052Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ053Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ053Id004AtgVerkehrsDatenKurzZeitGeschwindigkeitsKlassenIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenKurzGeschwindigkeitsKlassenZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ053Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ053Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ053Id036AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ053Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ053Id004AtgVerkehrsDatenKurzZeitGeschwindigkeitsKlassenIntervallAspExterneErfassung(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ053Id036AtgVerkehrsDatenKurzZeitGeschwindigkeitsKlassenIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ053Id004AtgVerkehrsDatenKurzZeitGeschwindigkeitsKlassenIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ053Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ053Id036AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ053Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ063Id004AtgKfzEinzelDatenFsAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Status-Byte aus Telegramm -----------------------------------------------------------------------------------
        int _Status_ = deBlock.getDeData().readUnsignedByteAsInt();

        data.getUnscaledValue("Status").set(_Status_);

        // FZKlasse-Byte aus Telegramm ---------------------------------------------------------------------------------
        int _FZKlasse_ = deBlock.getDeData().readUnsignedByteAsInt();

        switch (_FZKlasse_) {
        case 1 :
        case 2 :
        case 3 :
        case 4 :
        case 5 :
        case 6 :
        case 7 :
        case 8 :
        case 9 :
        case 10 :
        case 11 :
        case 32 :
        case 33 :
        case 64 :
            data.getUnscaledValue("FZKlasse").set(_FZKlasse_);

            break;

        default :
            debug.warning("FZKlasse-Wert ungültig : " + _FZKlasse_ + Debug.NEWLINE + "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE + deBlock.toString());

            return resultData;
        }

        // vKfz und Fahrtrichung aus Telegramm -------------------------------------------------------------------------
        int _vKfz_          = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        int _Fahrtrichtung_ = _vKfz_ >>> 15;

        data.getUnscaledValue("vKfz").set(_vKfz_ & 0x7fff);
        data.getUnscaledValue("Fahrtrichtung").set(_Fahrtrichtung_);

        // Belegzeit-Byte aus Telegramm --------------------------------------------------------------------------------
        int _Belegzeit_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();

        data.getUnscaledValue("Belegzeit").set(_Belegzeit_);

        // tNetto-Byte aus Telegramm -----------------------------------------------------------------------------------
        int _tNetto_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();

        data.getUnscaledValue("tNetto").set(_tNetto_);

        // FZLänge-Byte aus Telegramm ----------------------------------------------------------------------------------
        int _FZLänge_ = deBlock.getDeData().readUnsignedByteAsInt();

        data.getUnscaledValue("FZLänge").set(_FZLänge_);

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    public ResultData Fg001Typ063Id004AtgTlsLveKfzEinzelDatenAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Status-Byte aus Telegramm -----------------------------------------------------------------------------------
        int _Status_ = deBlock.getDeData().readUnsignedByteAsInt();

        data.getUnscaledValue("Status").set(_Status_);

        // FZKlasse-Byte aus Telegramm ---------------------------------------------------------------------------------
        int _FZKlasse_ = deBlock.getDeData().readUnsignedByteAsInt();

        switch (_FZKlasse_) {
        case 1 :
        case 2 :
        case 3 :
        case 4 :
        case 5 :
        case 6 :
        case 7 :
        case 8 :
        case 9 :
        case 10 :
        case 11 :
        case 32 :
        case 33 :
        case 64 :
            data.getUnscaledValue("FZKlasse").set(_FZKlasse_);

            break;

        default :
            debug.warning("FZKlasse-Wert ungültig : " + _FZKlasse_ + Debug.NEWLINE + "De-Block (Osi7Adresse-DeNummer-FG-Typ-Id): " + deBlock.getLongKey() + " verworfen:" + Debug.NEWLINE + deBlock.toString());

            return resultData;
        }

        // vKfz und Fahrtrichung aus Telegramm -------------------------------------------------------------------------
        int _vKfz_          = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        int _Fahrtrichtung_ = _vKfz_ >>> 15;

        data.getUnscaledValue("vKfz").set(_vKfz_ & 0x7fff);
        data.getUnscaledValue("Fahrtrichtung").set(_Fahrtrichtung_);

        // Belegzeit-Byte aus Telegramm --------------------------------------------------------------------------------
        int _Belegzeit_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();

        data.getUnscaledValue("Belegzeit").set(_Belegzeit_);

        // tNetto-Byte aus Telegramm -----------------------------------------------------------------------------------
        int _tNetto_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();

        data.getUnscaledValue("tNetto").set(_tNetto_);

        // FZLänge-Byte aus Telegramm ----------------------------------------------------------------------------------
        int _FZLänge_ = deBlock.getDeData().readUnsignedByteAsInt();

        data.getUnscaledValue("FZLänge").set(_FZLänge_);

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ063Id004AtgTlsLveKfzEinzelDatenAspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ063Id036AtgTlsLveKfzEinzelDatenAspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ063Id004AtgTlsLveKfzEinzelDatenAspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ065Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ065Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ065Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ065Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ066Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ066Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ066Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ066Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ067Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ067Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ067Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ067Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ068Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ068Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ068Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ068Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ069Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ069Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ069Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ069Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ070Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ070Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ070Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ070Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ071Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ071Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ071Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ071Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ072Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ072Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ072Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ072Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ073Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ073Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ073Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ073Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ074Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ074Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ074Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ074Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ075Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ075Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ075Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ075Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ076Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ076Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ076Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ076Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ077Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ077Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ077Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ077Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ078Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ078Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ078Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ078Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = VerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    // Spezialbehandlung zum Erzeugen der Attributgruppe für Version 10Bis23 aus Daten der Version 24
    public ResultData Fg001Typ079Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Mehrfachverarbeitung (zur Sicherheit den Lesezeiger nochmal zurücksetzen)
        deBlock.getDeData().rewindReadPosition();

        // Intervalllänge aus IntervalldatenHeader ---------------------------------------------------------------------
        data.getTimeValue("T").setSeconds(_eakConversionModul.getLveIntervalDuration());

        // Alle Werte jeweils auf Zustand "nicht ermittelbar" setzen.
        final String[] fzNames = { "Kfz", "PkwÄ", "KfzNk", "PkwG", "Pkw", "Krad", "Lfw", "LkwÄ", "PkwA", "Lkw", "Bus", "LkwK", "LkwA", "SattelKfz" };

        for (String fzName : fzNames) {
            data.getUnscaledValue("q" + fzName).setText("nicht ermittelbar");
            data.getUnscaledValue("v" + fzName).setText("nicht ermittelbar");
            data.getUnscaledValue("s" + fzName).setText("nicht ermittelbar");
            data.getUnscaledValue("v85" + fzName).setText("nicht ermittelbar");
            data.getUnscaledArray("q" + fzName + "GeschwKlasse").setLength(0);
        }

        if (deBlock.getTyp() == 79) {

            // TLS Rohdaten aus DE-Block holen
            int   _qKfzNk_     = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qKrad_      = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qPkw_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qLfw_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qPkwA_      = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qLkw_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qLkwA_      = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qBus_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _vLVo_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _vSGV_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _vBPA_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _sLVo_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _sSGV_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _sBPA_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _v85LVo_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v85SGV_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v85BPA_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v15LVo_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v15SGV_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v15BPA_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _countLVo_   = deBlock.getDeData().readUnsignedByteAsInt();
            int[] _qKlasseLVo_ = new int[_countLVo_];

            for (int i = 0; i < _countLVo_; i++) {
                _qKlasseLVo_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            int   _countSGV_   = deBlock.getDeData().readUnsignedByteAsInt();
            int[] _qKlasseSGV_ = new int[_countSGV_];

            for (int i = 0; i < _countSGV_; i++) {
                _qKlasseSGV_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            int   _countBPA_   = deBlock.getDeData().readUnsignedByteAsInt();
            int[] _qKlasseBPA_ = new int[_countBPA_];

            for (int i = 0; i < _countBPA_; i++) {
                _qKlasseBPA_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            // TLS Daten an ATG (Version 10Bis23) zuweisen
            data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
            data.getUnscaledValue("qKrad").set(_qKrad_);
            data.getUnscaledValue("qPkw").set(_qPkw_);
            data.getUnscaledValue("qLfw").set(_qLfw_);
            data.getUnscaledValue("qPkwA").set(_qPkwA_);
            data.getUnscaledValue("qLkw").set(_qLkw_);
            data.getUnscaledValue("qLkwA").set(_qLkwA_);
            data.getUnscaledValue("qSattelKfz").set(_qSattelKfz_);
            data.getUnscaledValue("qBus").set(_qBus_);

            // Übernahme der Geschwindigkeiten ist nicht sinnvoll:
            // a) v und s Geschwindigkeiten liegen im Bereich 0-6553,4 km/h
            // b) für v85 und v15 Geschwindigkeiten sowie für Geschwindigkeitsklassen
            // fehlen die passenden FZ-Gruppen
            // c) bei alternativer Zuordnung der Werte aus den Geschwindigkeitsklassen
            // (qPkwÄ ~ qLVo, qLkwÄ = qSGV+qBPA) können später Probleme mit den
            // Klassengrenzen auftreten
            // ! der auskommentierte Code ist getestet und funktioniert !
            //// Geschwindigkeitsklassen qLVo als PkwÄ einlesen (stimmt fast)
            // data.getUnscaledArray("qPkwÄGeschwKlasse").setLength(_countLVo_);
            // for (int i = 0; i < _countLVo_; i++) {
            // data.getUnscaledArray("qPkwÄGeschwKlasse").getValue(i).set(_qKlasseLVo_[i]);
            // }
            ////  Geschwindigkeitsklassen (qSGV+qBPA) als LkwÄ einlesen
            // if (_countSGV_==_countBPA_) {
            // data.getUnscaledArray("qLkwÄGeschwKlasse").setLength(_countSGV_);
            // for (int i = 0; i < _countSGV_; i++) {
            // data.getUnscaledArray("qLkwÄGeschwKlasse").getValue(i)
            // .set(Math.min(_qKlasseSGV_[i] + _qKlasseBPA_[i],65535));
            // }
            // }
        } else {
            debug.warning("Nicht erlaubter LVE-Langzeittyp-Typ: " + deBlock.getTyp());
        }

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data, false);

        return resultData;
    }

    // ----------------------------------------------------------------------
    // Ergebnismeldung Datenversion 24 (ID4-Spontan und ID36-Aus-Puffer)
    // 1. Verarbeitung -> Attributgruppe Version 24
    // 2. Verarbeitung -> Attributgruppe Version 10 Bis 23
    // 3. Verarbeitung -> Attributgruppe VerkehrsDatenLangZeitIntervall (FS)
    // ----------------------------------------------------------------------
    public ResultData Fg001Typ079Id004AtgTlsLveErgebnisMeldungVersion24AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Verarbeitung des DE-Blocks für Datenversion 24 (siehe nachfolgend)
        ResultData resultData = TlsLveErgebnisMeldungVersion24AspTlsAntwort(deBlock, data, dataDescription);

        // als Online-Daten an den DaV übergeben.
        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), false);
    }

    // Spezialbehandlung zum Erzeugen der Attributgruppe für FS-bezogene
    // Intervalldaten aus den Daten der TLS Datenversion 24
    public ResultData Fg001Typ079Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Mehrfachverarbeitung (zur Sicherheit den Lesezeiger nochmal zurücksetzen)
        deBlock.getDeData().rewindReadPosition();

        // Intervalllänge aus IntervalldatenHeader ---------------------------------------------------------------------
        data.getTimeValue("T").setSeconds(_eakConversionModul.getLveIntervalDuration());

        if (deBlock.getTyp() == 79) {

            // TLS-Rohdaten aus DE-Block holen
            int   _qKfzNk_     = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qKrad_      = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qPkw_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qLfw_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qPkwA_      = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qLkw_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qLkwA_      = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qBus_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _vLVo_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _vSGV_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _vBPA_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _sLVo_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _sSGV_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _sBPA_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _v85LVo_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v85SGV_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v85BPA_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v15LVo_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v15SGV_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v15BPA_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _countLVo_   = deBlock.getDeData().readUnsignedByteAsInt();
            int[] _qKlasseLVo_ = new int[_countLVo_];

            for (int i = 0; i < _countLVo_; i++) {
                _qKlasseLVo_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            int   _countSGV_   = deBlock.getDeData().readUnsignedByteAsInt();
            int[] _qKlasseSGV_ = new int[_countSGV_];

            for (int i = 0; i < _countSGV_; i++) {
                _qKlasseSGV_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            int   _countBPA_   = deBlock.getDeData().readUnsignedByteAsInt();
            int[] _qKlasseBPA_ = new int[_countBPA_];

            for (int i = 0; i < _countBPA_; i++) {
                _qKlasseBPA_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            // Werte jeweils auf Zustand "nicht ermittelbar" setzen.
            final String[] fzNames   = { "Kfz", "PkwÄ", "KfzNk", "PkwG", "Pkw", "Krad", "Lfw", "LkwÄ", "PkwA", "Lkw", "Bus", "LkwK", "LkwA", "SattelKfz" };
            final String[] praefixes = { "q", "v", "s", "v85" };

            for (String fzName : fzNames) {
                for (String praefix : praefixes) {
                    String valString = praefix + fzName;

                    data.getItem(valString).getUnscaledValue("Wert").setText("nicht ermittelbar");
                    data.getItem(valString).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                    data.getItem(valString).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                    data.getItem(valString).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                    data.getItem(valString).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                    data.getItem(valString).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                    data.getItem(valString).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                    data.getItem(valString).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                    data.getItem(valString).getItem("Güte").getUnscaledValue("Index").set(-1);
                    data.getItem(valString).getItem("Güte").getUnscaledValue("Verfahren").set(0);
                }

                data.getArray("q" + fzName + "GeschwKlasse").setLength(0);
            }

            // Daten zuweisen bzw. im Telegramm nicht vorhandene Daten auf
            // "nicht ermittelbar" lassen
            // Wert 65535 = "nicht ermittelbar" ({@see tls16BitToInt(int)})
            data.getItem("qKfzNk").getUnscaledValue("Wert").set(tls16BitToInt(_qKfzNk_));
            data.getItem("qKfzNk").getItem("Güte").getScaledValue("Index").set(1.0);
            data.getItem("qKrad").getUnscaledValue("Wert").set(tls16BitToInt(_qKrad_));
            data.getItem("qKrad").getItem("Güte").getScaledValue("Index").set(1.0);
            data.getItem("qPkw").getUnscaledValue("Wert").set(tls16BitToInt(_qPkw_));
            data.getItem("qPkw").getItem("Güte").getScaledValue("Index").set(1.0);
            data.getItem("qLfw").getUnscaledValue("Wert").set(tls16BitToInt(_qLfw_));
            data.getItem("qLfw").getItem("Güte").getScaledValue("Index").set(1.0);
            data.getItem("qPkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwA_));
            data.getItem("qPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            data.getItem("qLkw").getUnscaledValue("Wert").set(tls16BitToInt(_qLkw_));
            data.getItem("qLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            data.getItem("qLkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwA_));
            data.getItem("qLkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            data.getItem("qSattelKfz").getUnscaledValue("Wert").set(tls16BitToInt(_qSattelKfz_));
            data.getItem("qSattelKfz").getItem("Güte").getScaledValue("Index").set(1.0);
            data.getItem("qBus").getUnscaledValue("Wert").set(tls16BitToInt(_qBus_));
            data.getItem("qBus").getItem("Güte").getScaledValue("Index").set(1.0);

            // Den Wert von qKfz auf die Summe der Einzelwerte setzen, da dieser für das BASt-Band benötigt wird
            if ((_qKfzNk_ == 0xffff)
                &&                                                           //
                (_qKrad_ == 0xffff)
                &&                                                           //
                (_qPkw_ == 0xffff)
                &&                                                           //
                (_qLfw_ == 0xffff)
                &&                                                           //
                (_qPkwA_ == 0xffff)
                &&                                                           //
                (_qLkw_ == 0xffff)
                &&                                                           //
                (_qLkwA_ == 0xffff)
                &&                                                           //
                (_qSattelKfz_ == 0xffff)
                &&                                                           //
                (_qBus_ == 0xffff)) {

                // Sind alle Einzelwerte nicht ermittelbar, dann bleibt auch qKfz auf nicht ermittelbar
                // also ist hier nichts zu tun
            } else {
                int _qKfz_ = tls16BitToIntOhneFehlerKennung(_qKfzNk_) +      //
                             tls16BitToIntOhneFehlerKennung(_qKrad_) +       //
                             tls16BitToIntOhneFehlerKennung(_qPkw_) +        //
                             tls16BitToIntOhneFehlerKennung(_qLfw_) +        //
                             tls16BitToIntOhneFehlerKennung(_qPkwA_) +       //
                             tls16BitToIntOhneFehlerKennung(_qLkw_) +        //
                             tls16BitToIntOhneFehlerKennung(_qLkwA_) +       //
                             tls16BitToIntOhneFehlerKennung(_qSattelKfz_) +  //
                             tls16BitToIntOhneFehlerKennung(_qBus_);

                // Wert aber nur speichern, wenn er noch innerhalb des gültigen Wertebereichs liegt
                if (_qKfz_ < 0xffff) {
                    data.getItem("qKfz").getUnscaledValue("Wert").set(_qKfz_);
                    data.getItem("qKfz").getItem("Güte").getScaledValue("Index").set(1.0);
                }
            }

            // Übernahme der Geschwindigkeiten ist nicht sinnvoll:
            // a) v und s Geschwindigkeiten liegen im Bereich 0-6553,4 km/h
            // b) für v85 und v15 Geschwindigkeiten sowie für Geschwindigkeitsklassen
            // fehlen die passenden FZ-Gruppen
            // c) bei alternativer Zuordnung der Werte aus den Geschwindigkeitsklassen
            // (qPkwÄ ~ qLVo, qLkwÄ = qSGV+qBPA) können später Probleme mit den
            // Klassengrenzen auftreten
            // ! der auskommentierte Code ist getestet und funktioniert !
            //// Geschwindigkeitsklassen qLVo als PkwÄ einlesen (stimmt fast)
            // Data.Array array;
            // array = data.getArray("qPkwÄGeschwKlasse");
            // array.setLength(_countLVo_);
            // for (int i = 0; i < _countLVo_; i++) {
            // array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasseLVo_[i]));
            // array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
            // array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
            // array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
            // array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
            // array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
            // array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
            // array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
            // array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
            // array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            // }
            //// Geschwindigkeitsklassen (qSGV+qBPA) als LkwÄ einlesen
            // if (_countSGV_==_countBPA_) {
            // array = data.getArray("qLkwÄGeschwKlasse");
            // array.setLength(_countSGV_);
            // for (int i = 0; i < _countSGV_; i++) {
            // array.getItem(i).getUnscaledValue("Wert")
            // .set(tls16BitToInt(Math.min(_qKlasseSGV_[i] + _qKlasseBPA_[i],65535)));
            // array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
            // array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
            // array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
            // array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
            // array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
            // array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
            // array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
            // array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
            // array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            // }
            // }
        } else {
            debug.warning("Nicht erlaubter LVE-Langzeittyp-Typ: " + deBlock.getTyp());
        }

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    public ResultData Fg001Typ079Id004AtgVerkehrsDatenLangZeitIntervallGeschwindigkeitVerteilungFsAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Mehrfachverarbeitung (zur Sicherheit den Lesezeiger nochmal zurücksetzen)
        deBlock.getDeData().rewindReadPosition();

        if (deBlock.getTyp() == 79) {

            // TLS-Rohdaten aus DE-Block holen
            int   _qKfzNk_     = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qKrad_      = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qPkw_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qLfw_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qPkwA_      = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qLkw_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qLkwA_      = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qBus_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _vLVo_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _vSGV_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _vBPA_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _sLVo_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _sSGV_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _sBPA_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _v85LVo_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v85SGV_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v85BPA_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v15LVo_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v15SGV_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v15BPA_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _countLVo_   = deBlock.getDeData().readUnsignedByteAsInt();
            int[] _qKlasseLVo_ = new int[_countLVo_];

            for (int i = 0; i < _countLVo_; i++) {
                _qKlasseLVo_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            int   _countSGV_   = deBlock.getDeData().readUnsignedByteAsInt();
            int[] _qKlasseSGV_ = new int[_countSGV_];

            for (int i = 0; i < _countSGV_; i++) {
                _qKlasseSGV_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            int   _countBPA_   = deBlock.getDeData().readUnsignedByteAsInt();
            int[] _qKlasseBPA_ = new int[_countBPA_];

            for (int i = 0; i < _countBPA_; i++) {
                _qKlasseBPA_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            // Intervalllänge aus IntervalldatenHeader, Zeitangabe von Sekunden in Stunden umrechnen
            data.getUnscaledValue("T").set(_eakConversionModul.getLveIntervalDuration() / 3600);

            // Sonstigen Werte setzen
            data.getUnscaledValue("qKfzNk").set(tls16BitToInt(_qKfzNk_));
            data.getUnscaledValue("qKrad").set(tls16BitToInt(_qKrad_));
            data.getUnscaledValue("qPkw").set(tls16BitToInt(_qPkw_));
            data.getUnscaledValue("qLfw").set(tls16BitToInt(_qLfw_));
            data.getUnscaledValue("qPkwA").set(tls16BitToInt(_qPkwA_));
            data.getUnscaledValue("qLkw").set(tls16BitToInt(_qLkw_));
            data.getUnscaledValue("qLkwA").set(tls16BitToInt(_qLkwA_));
            data.getUnscaledValue("qSattelKfz").set(tls16BitToInt(_qSattelKfz_));
            data.getUnscaledValue("qBus").set(tls16BitToInt(_qBus_));

            int _qSGV_ = 0xFFFF;  // Berechneter Wert = qLkw + qLkwA + qSattelKfz

            if ((_qLkw_ != 0xFFFF) && (_qLkwA_ != 0xFFFF) && (_qSattelKfz_ != 0xFFFF)) {
                _qSGV_ = _qLkw_ + _qLkwA_ + _qSattelKfz_;
            }

            data.getUnscaledValue("qSGV").set(tls16BitToInt(_qSGV_));

            // Hilfsgröße zur Berechnung des Anteils SGV
            int _qKfzGesamt_ = 0;

            if ((_qKfzNk_ != 0xFFFF) && (_qKrad_ != 0xFFFF) && (_qPkw_ != 0xFFFF) && (_qLfw_ != 0xFFFF) && (_qPkwA_ != 0xFFFF) && (_qLkw_ != 0xFFFF) && (_qLkwA_ != 0xFFFF) && (_qSattelKfz_ != 0xFFFF) && (_qBus_ != 0xFFFF)) {
                _qKfzGesamt_ = _qKfzNk_ + _qKrad_ + _qPkw_ + _qLfw_ + _qPkwA_ + _qLkw_ + _qLkwA_ + _qSattelKfz_ + _qBus_;
            }

            int _anteilSGV_ = -100001;  // Berechneter Wert = qSGV / qKfzGesamt * 100%

            if ((_qSGV_ != 0xFFFF) && (_qKfzGesamt_ != 0)) {
                _anteilSGV_ = (int) ((double) _qSGV_ / (double) _qKfzGesamt_ * 100.0);
            }

            data.getUnscaledValue("anteilSGV").set(_anteilSGV_);
            data.getUnscaledValue("vLVo").set(tls16BitTo8BitInt(_vLVo_));
            data.getUnscaledValue("vSGV").set(tls16BitTo8BitInt(_vSGV_));
            data.getUnscaledValue("vBPA").set(tls16BitTo8BitInt(_vBPA_));
            data.getUnscaledValue("sLVo").set(tls16BitTo8BitInt(_sLVo_));
            data.getUnscaledValue("sSGV").set(tls16BitTo8BitInt(_sSGV_));
            data.getUnscaledValue("sBPA").set(tls16BitTo8BitInt(_sBPA_));
            data.getUnscaledValue("v85LVo").set(tls8BitToInt(_v85LVo_));
            data.getUnscaledValue("v85SGV").set(tls8BitToInt(_v85SGV_));
            data.getUnscaledValue("v85BPA").set(tls8BitToInt(_v85BPA_));
            data.getUnscaledValue("v15LVo").set(tls8BitToInt(_v15LVo_));
            data.getUnscaledValue("v15SGV").set(tls8BitToInt(_v15SGV_));
            data.getUnscaledValue("v15BPA").set(tls8BitToInt(_v15BPA_));

            Data.Array array;

            array = data.getArray("qLVoGeschwKlasse");
            array.setLength(_countLVo_);

            for (int i = 0; i < _countLVo_; i++) {
                array.getUnscaledValue(i).set(tls16BitToInt(_qKlasseLVo_[i]));
            }

            array = data.getArray("qSGVGeschwKlasse");
            array.setLength(_countSGV_);

            for (int i = 0; i < _countSGV_; i++) {
                array.getUnscaledValue(i).set(tls16BitToInt(_qKlasseSGV_[i]));
            }

            array = data.getArray("qBPAGeschwKlasse");
            array.setLength(_countBPA_);

            for (int i = 0; i < _countBPA_; i++) {
                array.getUnscaledValue(i).set(tls16BitToInt(_qKlasseBPA_[i]));
            }

            // Geschwindigkeitsklassengrenzen eintragen
            array = data.getArray("vGrenzLVo");
            array.setLength(_vGrenzLVo.length);

            for (int i = 0; i < _vGrenzLVo.length; i++) {
                array.getUnscaledValue(i).set(tls8BitToInt(_vGrenzLVo[i]));
            }

            array = data.getArray("vGrenzSGV");
            array.setLength(_vGrenzSGV.length);

            for (int i = 0; i < _vGrenzSGV.length; i++) {
                array.getUnscaledValue(i).set(tls8BitToInt(_vGrenzSGV[i]));
            }

            array = data.getArray("vGrenzBPA");
            array.setLength(_vGrenzBPA.length);

            for (int i = 0; i < _vGrenzBPA.length; i++) {
                array.getUnscaledValue(i).set(tls8BitToInt(_vGrenzBPA[i]));
            }
        } else {
            debug.warning("Nicht erlaubter LVE-Langzeittyp-Typ: " + deBlock.getTyp());
        }

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    public ResultData Fg001Typ079Id036AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = Fg001Typ079Id004AtgTlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(deBlock, data, dataDescription);

        // TROTZ ERGEBNIS AUS PUFFER als Online-Daten an den DaV übergeben.
        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), false);
    }

    public ResultData Fg001Typ079Id036AtgTlsLveErgebnisMeldungVersion24AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Verarbeitung des DE-Blocks für Datenversion 24 (siehe nachfolgend)
        ResultData resultData = TlsLveErgebnisMeldungVersion24AspTlsAntwort(deBlock, data, dataDescription);

        // TROTZ ERGIBNIS AUS PUFFER als Online-Daten an den DaV übergeben.
        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), false);
    }

    public ResultData Fg001Typ079Id036AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = Fg001Typ079Id004AtgVerkehrsDatenLangZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        // TROTZ ERGEBNIS AUS PUFFER als Online-Daten an den DaV übergeben.
        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), false);
    }

    public ResultData Fg001Typ079Id036AtgVerkehrsDatenLangZeitIntervallGeschwindigkeitVerteilungFsAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = Fg001Typ079Id004AtgVerkehrsDatenLangZeitIntervallGeschwindigkeitVerteilungFsAspExterneErfassung(deBlock, data, dataDescription);

        // TROTZ ERGEBNIS AUS PUFFER als Online-Daten an den DaV übergeben.
        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), false);
    }

    public ResultData Fg001Typ096Id004AtgTlsSveErgebnisMeldungVersion0Bis1AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // kKfz-Byte aus Telegramm -------------------------------------------------------------------------------------
        int _kKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();

        data.getUnscaledValue("kKfz").set(_kKfz_);

        // vKfzReise-Byte aus Telegramm --------------------------------------------------------------------------------
        int _vKfzReise_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();

        data.getUnscaledValue("vKfzReise").set(_vKfzReise_);

        // Sonstige Werte auf "nicht ermittelbar" setzen ---------------------------------------------------------------
        data.getUnscaledValue("kPkw").setText("nicht ermittelbar");
        data.getUnscaledValue("kLkw").setText("nicht ermittelbar");
        data.getUnscaledValue("vPkwReise").setText("nicht ermittelbar");
        data.getUnscaledValue("vLkwReise").setText("nicht ermittelbar");

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    public ResultData Fg001Typ097Id004AtgTlsSveErgebnisMeldungVersion0Bis1AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // kKfz-Byte aus Telegramm -------------------------------------------------------------------------------------
        int _kKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();

        data.getUnscaledValue("kKfz").set(_kKfz_);

        // vKfzReise-Byte aus Telegramm --------------------------------------------------------------------------------
        int _vKfzReise_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();

        data.getUnscaledValue("vKfzReise").set(_vKfzReise_);

        // kPkw-Byte aus Telegramm -------------------------------------------------------------------------------------
        int _kPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();

        data.getUnscaledValue("kPkw").set(_kPkw_);

        // kLkw-Byte aus Telegramm -------------------------------------------------------------------------------------
        int _kLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();

        data.getUnscaledValue("kLkw").set(_kLkw_);

        // vPkwReise-Byte aus Telegramm --------------------------------------------------------------------------------
        int _vPkwReise_ = deBlock.getDeData().readUnsignedByteAsInt();

        data.getUnscaledValue("vPkwReise").set(_vPkwReise_);

        // vLkwReise-Byte aus Telegramm --------------------------------------------------------------------------------
        int _vLkwReise_ = deBlock.getDeData().readUnsignedByteAsInt();

        data.getUnscaledValue("vLkwReise").set(_vLkwReise_);

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ097Id004AtgTlsSveErgebnisMeldungVersion0Bis1AspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ097Id036AtgTlsSveErgebnisMeldungVersion0Bis1AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ097Id004AtgTlsSveErgebnisMeldungVersion0Bis1AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ113Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ113Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ113Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ113Id036AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ113Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ113Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ113Id036AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ113Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ114Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ114Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ114Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ114Id036AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ114Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ114Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ114Id036AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ114Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ115Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ115Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ115Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ115Id036AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ115Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ115Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ115Id036AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ115Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ116Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ116Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ116Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ116Id036AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ116Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ116Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ116Id036AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ116Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    public ResultData Fg001Typ117Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return TlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ117Id004AtgVerkehrsDatenKurzZeitGeschwindigkeitsKlassenIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenKurzGeschwindigkeitsKlassenZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    public ResultData Fg001Typ117Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        return VerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ117Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ117Id036AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ117Id004AtgTlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ117Id004AtgVerkehrsDatenKurzZeitGeschwindigkeitsKlassenIntervallAspExterneErfassung(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ117Id036AtgVerkehrsDatenKurzZeitGeschwindigkeitsKlassenIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ117Id004AtgVerkehrsDatenKurzZeitGeschwindigkeitsKlassenIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg001Typ117Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg001Typ117Id036AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 4, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg001Typ117Id004AtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg255Typ029Id002AtgTlsGloKanalSteuerungAspParameterIst(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg255Typ029Id034AtgTlsGloKanalSteuerungAspParameterIst(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 2, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg255Typ029Id002AtgTlsGloKanalSteuerungAspParameterIst(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    /**
     * Entspricht {@link Fg001Default#Fg255Typ036Id003AtgTlsGloGeographischeKenndatenAspTlsZustand(de.bsvrz.kex.tls.osi7.DeBlock,
     * de.bsvrz.dav.daf.main.Data, de.bsvrz.dav.daf.main.DataDescription)}, jedoch werden die Daten als nachgeliefert gekennzeichnet.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    public ResultData Fg255Typ036Id035AtgTlsGloGeographischeKenndatenAspTlsZustand(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Generierte Methode: Standardverarbeitung wie bei Id 3, aber als "nachgelieferte" Daten an den DaV übergeben.
        ResultData resultData = Fg255Typ036Id003AtgTlsGloGeographischeKenndatenAspTlsZustand(deBlock, data, dataDescription);

        return new ResultData(_de.getDe(), dataDescription, resultData.getDataTime(), resultData.getData(), true);
    }

    //~ GET METHODEN ==========================================================

    public int getKindOfAverage() {
        return _kindOfAverage;
    }

    //~ METHODEN ==============================================================

    /**
     * Wandelt einen 16Bit Wert mit einer Nachkommastelle (Kodierung laut TLS 0...6553,4 km/h, 65535) in einen 16-Bit Wert
     * um, wobei allerdings der Wertbereich wieder auf sinnvolle Werte im Bereich 0-254 eingeschränkt wird. Dazu wird
     * geprüft:
     * <p/>
     * Wert == 0xffff. In diesem Fall wird 65535 zurückgegeben, so dass dieser alsunscaledValue direkt gesetzt werden kann
     * (entspricht dem Zustand "nicht ermittelbar").
     * <p/>
     * Wert > 2540. Dann wird 65535 zurückgegeben (entspricht dem Zustand "nicht ermittelbar").
     * <p/>
     * sonst: Wert, also von 0,0 bis 254,0
     *
     * @param value Der zu prüfende Wert (der als 16 Bit vorzeichenlos interpretiert wird)
     *
     * @return value, wenn ungleich 0xffff und <2540, sonst -1.
     */
    private int tls16BitTo16BitInt(int value) {
        if (value == 0xffff) {
            return 0xffff;
        }

        if (value > 2540) {
            return 0xffff;
        }

        return value;
    }

    /**
     * Wandelt einen 16Bit Wert mit einer Nachkommastelle (Kodierung laut TLS 0...6553,4 km/h, 65535) in einen 8-Bit Wert
     * um. Dazu wird geprüft:
     * <p/>
     * Wert == 0xffff. In diesem Fall wird -1 zurückgegeben, so dass dieser alsunscaledValue direkt gesetzt werden kann
     * (entspricht dem Zustand "nicht ermittelbar").
     * <p/>
     * Wert >= 2540. Dann wird -1 zurückgegeben (entspricht dem Zustand "nicht ermittelbar").
     * <p/>
     * sonst: (Wert + 5) / 10, also von 0 bis 253
     *
     * @param value Der zu prüfende Wert (der als 16 Bit vorzeichenlos interpretiert wird)
     *
     * @return (value plus 5) / 10, wenn ungleich 0xffff und < 2540, sonst -1.
     */
    private int tls16BitTo8BitInt(int value) {
        if (value == 0xffff) {
            return -1;
        }

        if (value >= 2540) {
            return -1;
        }

        return (value + 5) / 10;
    }

    /**
     * Prüft, ob der übergebene Wert == 0xffff ist. In diesem Fall wird -1 zurückgegeben, so dass dieser als unscaledValue
     * direkt gesetzt werden kann (entspricht dem Zustand "nicht ermittelbar").
     *
     * @param value Der zu prüfende Wert (der als 16 Bit vorzeichenlos interpretiert wird)
     *
     * @return value, wenn ungleich 0xffff, sonst -1.
     */
    private int tls16BitToInt(int value) {
        if (value == 0xffff) {
            return -1;
        } else {
            return value;
        }
    }

    /**
     * Prüft, ob der übergebene Wert == 0xffff ist. In diesem Fall wird 0 als gültiger Wert zurückgegeben.
     *
     * @param value Der zu prüfende Wert (der als 16 Bit vorzeichenlos interpretiert wird)
     *
     * @return value, wenn ungleich 0xffff, sonst 0.
     */

    private int tls16BitToIntOhneFehlerKennung(int value) {
        if (value == 0xffff) {
            return 0;
        } else {
            return value;
        }
    }






    /**
     * Prüft, ob der übergebene Wert == 0xff ist. In diesem Fall wird -1 zurückgegeben, so dass dieser als unscaledValue
     * direkt gesetzt werden kann (entspricht dem Zustand "nicht ermittelbar").
     *
     * @param value Der zu prüfende Wert (der als 8 Bit vorzeichenlos interpretiert wird)
     *
     * @return value, wenn ungleich 255, sonst -1.
     */
    private int tls8BitToInt(int value) {
        if (value == 0xff) {
            return -1;
        } else {
            return value;
        }
    }

    /**
     * Verarbeitet alls Telegrammversionen der TLS Kurzeit Version 0-4 (Typ 49/113 -53/117).
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    private ResultData TlsLveErgebnisMeldungVersion0Bis4AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Intervalllänge aus IntervalldatenHeader ---------------------------------------------------------------------
        data.getTimeValue("T").setSeconds(_eakConversionModul.getLveIntervalDuration());

        int              _qKfz_;               // qKfz-Wert aus Telegramm
        int              _qLkwÄ_;              // qLkw-Wert aus Telegramm
        int              _vPkwÄ_;              // qPkwÄ-Wert aus Telegramm
        int              _vLkwÄ_;              // vLkwÄ-Wert aus Telegramm
        int              _tNetto_;             // tNetto-Wert aus Telegramm
        int              _b_;                  // Belegungs-Wert aus Telegramm
        int              _sKfz_;               // Streuung Kfz-Wert aus Telegramm
        int              _vKfz_;               // vKfz-Wert aus Telegramm
        int              countQPkwÄGeschwKlasse = 0;
        int[]            _qPkwÄGeschwKlasse_;  // Geschwindigkeitsklasse qPkwÄ-Werte aus Telegramm
        int              countQLkwÄGeschwKlasse = 0;
        int[]            _qLkwÄGeschwKlasse_;  // Geschwindigkeitsklasse qPkwÄ-Wertte aus Telegramm
        Data.NumberArray _KlassePkw_;
        Data.NumberArray _KlasseLkw_;

        // Werte jeweils auf Zustand "nicht ermittelbar" setzen.
        data.getUnscaledValue("qKfz").setText("nicht ermittelbar");
        data.getUnscaledValue("qLkwÄ").setText("nicht ermittelbar");
        data.getUnscaledValue("vPkwÄ").setText("nicht ermittelbar");
        data.getUnscaledValue("vLkwÄ").setText("nicht ermittelbar");
        data.getUnscaledValue("tNetto").setText("nicht ermittelbar");
        data.getUnscaledValue("b").setText("nicht ermittelbar");
        data.getUnscaledValue("sKfz").setText("nicht ermittelbar");
        data.getUnscaledValue("vKfz").setText("nicht ermittelbar");
        data.getUnscaledArray("qPkwÄGeschwKlasse").setLength(0);
        data.getUnscaledArray("qLkwÄGeschwKlasse").setLength(0);

        // Telegrammabhängig die Daten einlesen, im Telegramm nicht vorhandene Daten auf "nicht ermittelbar" lassen
        switch (deBlock.getTyp()) {
        case 49 :  // Version 0 - 8-Bit-Format
            _qKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);

            break;

        case 50 :  // Version 1 - 8-Bit-Format
            _qKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _tNetto_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("tNetto").set(_tNetto_);

            break;

        case 51 :  // Version 2 - 8-Bit-Format
            _qKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _b_ = deBlock.getDeData().readUnsignedByteAsInt();

            if (_b_ != 255) {
                if (_b_ > 100) {
                    debug.warning("Belegung von " + _b_ + "% > 100% erhalten! Wert wurde auf 'nicht ermittelbar' geändert!");
                } else {
                    data.getUnscaledValue("b").set(_b_);
                }
            }

            break;

        case 52 :  // Version 3 - 8-Bit-Format
            _qKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _tNetto_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("tNetto").set(_tNetto_);
            _b_ = deBlock.getDeData().readUnsignedByteAsInt();

            if (_b_ != 255) {
                if (_b_ > 100) {
                    debug.warning("Belegung von " + _b_ + "% > 100% erhalten! Wert wurde auf 'nicht ermittelbar' geändert!");
                } else {
                    data.getUnscaledValue("b").set(_b_);
                }
            }

            _sKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sKfz").set(_sKfz_);
            _vKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vKfz").set(_vKfz_);

            break;

        case 53 :  // Version 4 - 8-Bit-Format
            _qKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _tNetto_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("tNetto").set(_tNetto_);
            _b_ = deBlock.getDeData().readUnsignedByteAsInt();

            if (_b_ != 255) {
                if (_b_ > 100) {
                    debug.warning("Belegung von " + _b_ + "% > 100% erhalten! Wert wurde auf 'nicht ermittelbar' geändert!");
                } else {
                    data.getUnscaledValue("b").set(_b_);
                }
            }

            _sKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sKfz").set(_sKfz_);
            _vKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vKfz").set(_vKfz_);

            // Geschwindigkeitsklassen qPkwÄ einlesen
            countQPkwÄGeschwKlasse = deBlock.getDeData().readUnsignedByteAsInt();
            _qPkwÄGeschwKlasse_    = new int[countQPkwÄGeschwKlasse];

            for (int i = 0; i < countQPkwÄGeschwKlasse; i++) {
                _qPkwÄGeschwKlasse_[i] = deBlock.getDeData().readUnsignedByteAsInt();
            }

            _KlassePkw_ = data.getUnscaledArray("qPkwÄGeschwKlasse");
            _KlassePkw_.setLength(countQPkwÄGeschwKlasse);

            for (int i = 0; i < countQPkwÄGeschwKlasse; i++) {
                _KlassePkw_.getValue(i).set(_qPkwÄGeschwKlasse_[i]);
            }

            // Geschwindigkeitsklassen qPkwÄ einlesen
            countQLkwÄGeschwKlasse = deBlock.getDeData().readUnsignedByteAsInt();
            _qLkwÄGeschwKlasse_    = new int[countQLkwÄGeschwKlasse];

            for (int i = 0; i < countQLkwÄGeschwKlasse; i++) {
                _qLkwÄGeschwKlasse_[i] = deBlock.getDeData().readUnsignedByteAsInt();
            }

            _KlasseLkw_ = data.getUnscaledArray("qLkwÄGeschwKlasse");
            _KlasseLkw_.setLength(countQLkwÄGeschwKlasse);

            for (int i = 0; i < countQLkwÄGeschwKlasse; i++) {
                _KlasseLkw_.getValue(i).set(_qLkwÄGeschwKlasse_[i]);
            }

            break;

        case 113 :  // Version 0 - 16-Bit-Format
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);

            break;

        case 114 :  // Version 1 - 16-Bit-Format
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _tNetto_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("tNetto").set(_tNetto_);

            break;

        case 115 :  // Version 2 - 16-Bit-Format
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _b_ = deBlock.getDeData().readUnsignedByteAsInt();

            if (_b_ != 255) {
                if (_b_ > 100) {
                    debug.warning("Belegung von " + _b_ + "% > 100% erhalten! Wert wurde auf 'nicht ermittelbar' geändert!");
                } else {
                    data.getUnscaledValue("b").set(_b_);
                }
            }

            break;

        case 116 :  // Version 3 - 16-Bit-Format
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _tNetto_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("tNetto").set(_tNetto_);
            _b_ = deBlock.getDeData().readUnsignedByteAsInt();

            if (_b_ != 255) {
                if (_b_ > 100) {
                    debug.warning("Belegung von " + _b_ + "% > 100% erhalten! Wert wurde auf 'nicht ermittelbar' geändert!");
                } else {
                    data.getUnscaledValue("b").set(_b_);
                }
            }

            _sKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sKfz").set(_sKfz_);
            _vKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vKfz").set(_vKfz_);

            break;

        case 117 :  // Version 4 - 16-Bit-Format
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _tNetto_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("tNetto").set(_tNetto_);
            _b_ = deBlock.getDeData().readUnsignedByteAsInt();

            if (_b_ != 255) {
                if (_b_ > 100) {
                    debug.warning("Belegung von " + _b_ + "% > 100% erhalten! Wert wurde auf 'nicht ermittelbar' geändert!");
                } else {
                    data.getUnscaledValue("b").set(_b_);
                }
            }

            _sKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sKfz").set(_sKfz_);
            _vKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vKfz").set(_vKfz_);

            // Geschwindigkeitsklassen qPkwÄ einlesen
            countQPkwÄGeschwKlasse = deBlock.getDeData().readUnsignedByteAsInt();
            _qPkwÄGeschwKlasse_    = new int[countQPkwÄGeschwKlasse];

            for (int i = 0; i < countQPkwÄGeschwKlasse; i++) {
                _qPkwÄGeschwKlasse_[i] = deBlock.getDeData().readUnsignedByteAsInt();
            }

            _KlassePkw_ = data.getUnscaledArray("qPkwÄGeschwKlasse");
            _KlassePkw_.setLength(countQPkwÄGeschwKlasse);

            for (int i = 0; i < countQPkwÄGeschwKlasse; i++) {
                _KlassePkw_.getValue(i).set(_qPkwÄGeschwKlasse_[i]);
            }

            // Geschwindigkeitsklassen qPkwÄ einlesen
            countQLkwÄGeschwKlasse = deBlock.getDeData().readUnsignedByteAsInt();
            _qLkwÄGeschwKlasse_    = new int[countQLkwÄGeschwKlasse];

            for (int i = 0; i < countQLkwÄGeschwKlasse; i++) {
                _qLkwÄGeschwKlasse_[i] = deBlock.getDeData().readUnsignedByteAsInt();
            }

            _KlasseLkw_ = data.getUnscaledArray("qLkwÄGeschwKlasse");
            _KlasseLkw_.setLength(countQLkwÄGeschwKlasse);

            for (int i = 0; i < countQLkwÄGeschwKlasse; i++) {
                _KlasseLkw_.getValue(i).set(_qLkwÄGeschwKlasse_[i]);
            }

            break;

        default :
            debug.warning("Unbekannter LVE-Kurzzeit-Typ (49/113 - 53/117): " + deBlock.getTyp());
        }

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        // DE-Daten-Ausfallüberwachung aufrufen und nächsten Zeitpunkt eintragen, an dem spätesten KEINE DATEN gesendet wird.
        DeAusfallUeberwachung.addAuftrag(_config, _de, dataDescription, "typ.deLve", _eakConversionModul.getTimeStamp(), _eakConversionModul.getLveIntervalDuration());

        return resultData;
    }

    /**
     * Verarbeitet alls Telegrammversionen der TLS Langzeit Version 10-23 (Typ 65 -78). Genaue Beschreibung bzg. Aufbau der
     * Telegramm in den einzelnen Versionen siehe TLS.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    private ResultData TlsLveErgebnisMeldungVersion10Bis23AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Intervalllänge aus IntervalldatenHeader ---------------------------------------------------------------------
        data.getTimeValue("T").setSeconds(_eakConversionModul.getLveIntervalDuration());

        int _qKfz_;
        int _qPkwÄ_;         // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _qKfzNk_;
        int _qPkwG_;
        int _qPkw_;
        int _qKrad_;
        int _qLfw_;
        int _qLkwÄ_;
        int _qPkwA_;
        int _qLkw_;
        int _qBus_;
        int _qLkwK_;
        int _qLkwA_;
        int _qSattelKfz_;
        int _vKfz_;
        int _vPkwÄ_;
        int _vKfzNk_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _vPkwG_;
        int _vPkw_;
        int _vKrad_;
        int _vLfw_;
        int _vLkwÄ_;
        int _vPkwA_;
        int _vLkw_;
        int _vBus_;
        int _vLkwK_;
        int _vLkwA_;
        int _vSattelKfz_;
        int _sKfz_;          // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _sPkwÄ_;
        int _sKfzNk_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _sPkwG_;
        int _sPkw_;
        int _sKrad_;
        int _sLfw_;
        int _sLkwÄ_;
        int _sPkwA_;
        int _sLkw_;
        int _sBus_;
        int _sLkwK_;
        int _sLkwA_;         // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _sSattelKfz_;
        int _v85Kfz_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _v85PkwÄ_;
        int _v85KfzNk_;      // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _v85PkwG_;       // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _v85Pkw_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _v85Krad_;       // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _v85Lfw_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _v85LkwÄ_;       // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _v85PkwA_;       // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _v85Lkw_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _v85Bus_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _v85LkwK_;       // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _v85LkwA_;       // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int _v85SattelKfz_;  // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int count = 0;
        int _qKlasse_;

        // Werte jeweils auf Zustand "nicht ermittelbar" setzen.
        data.getUnscaledValue("qKfz").setText("nicht ermittelbar");
        data.getUnscaledValue("qPkwÄ").setText("nicht ermittelbar");
        data.getUnscaledValue("qKfzNk").setText("nicht ermittelbar");
        data.getUnscaledValue("qPkwG").setText("nicht ermittelbar");
        data.getUnscaledValue("qPkw").setText("nicht ermittelbar");
        data.getUnscaledValue("qKrad").setText("nicht ermittelbar");
        data.getUnscaledValue("qLfw").setText("nicht ermittelbar");
        data.getUnscaledValue("qLkwÄ").setText("nicht ermittelbar");
        data.getUnscaledValue("qPkwA").setText("nicht ermittelbar");
        data.getUnscaledValue("qLkw").setText("nicht ermittelbar");
        data.getUnscaledValue("qBus").setText("nicht ermittelbar");
        data.getUnscaledValue("qLkwK").setText("nicht ermittelbar");
        data.getUnscaledValue("qLkwA").setText("nicht ermittelbar");
        data.getUnscaledValue("qSattelKfz").setText("nicht ermittelbar");
        data.getUnscaledValue("vKfz").setText("nicht ermittelbar");
        data.getUnscaledValue("vPkwÄ").setText("nicht ermittelbar");
        data.getUnscaledValue("vKfzNk").setText("nicht ermittelbar");
        data.getUnscaledValue("vPkwG").setText("nicht ermittelbar");
        data.getUnscaledValue("vPkw").setText("nicht ermittelbar");
        data.getUnscaledValue("vKrad").setText("nicht ermittelbar");
        data.getUnscaledValue("vLfw").setText("nicht ermittelbar");
        data.getUnscaledValue("vLkwÄ").setText("nicht ermittelbar");
        data.getUnscaledValue("vPkwA").setText("nicht ermittelbar");
        data.getUnscaledValue("vLkw").setText("nicht ermittelbar");
        data.getUnscaledValue("vBus").setText("nicht ermittelbar");
        data.getUnscaledValue("vLkwK").setText("nicht ermittelbar");
        data.getUnscaledValue("vLkwA").setText("nicht ermittelbar");
        data.getUnscaledValue("vSattelKfz").setText("nicht ermittelbar");
        data.getUnscaledValue("sKfz").setText("nicht ermittelbar");
        data.getUnscaledValue("sPkwÄ").setText("nicht ermittelbar");
        data.getUnscaledValue("sKfzNk").setText("nicht ermittelbar");
        data.getUnscaledValue("sPkwG").setText("nicht ermittelbar");
        data.getUnscaledValue("sPkw").setText("nicht ermittelbar");
        data.getUnscaledValue("sKrad").setText("nicht ermittelbar");
        data.getUnscaledValue("sLfw").setText("nicht ermittelbar");
        data.getUnscaledValue("sLkwÄ").setText("nicht ermittelbar");
        data.getUnscaledValue("sPkwA").setText("nicht ermittelbar");
        data.getUnscaledValue("sLkw").setText("nicht ermittelbar");
        data.getUnscaledValue("sBus").setText("nicht ermittelbar");
        data.getUnscaledValue("sLkwK").setText("nicht ermittelbar");
        data.getUnscaledValue("sLkwA").setText("nicht ermittelbar");
        data.getUnscaledValue("sSattelKfz").setText("nicht ermittelbar");
        data.getUnscaledValue("v85Kfz").setText("nicht ermittelbar");
        data.getUnscaledValue("v85PkwÄ").setText("nicht ermittelbar");
        data.getUnscaledValue("v85KfzNk").setText("nicht ermittelbar");
        data.getUnscaledValue("v85PkwG").setText("nicht ermittelbar");
        data.getUnscaledValue("v85Pkw").setText("nicht ermittelbar");
        data.getUnscaledValue("v85Krad").setText("nicht ermittelbar");
        data.getUnscaledValue("v85Lfw").setText("nicht ermittelbar");
        data.getUnscaledValue("v85LkwÄ").setText("nicht ermittelbar");
        data.getUnscaledValue("v85PkwA").setText("nicht ermittelbar");
        data.getUnscaledValue("v85Lkw").setText("nicht ermittelbar");
        data.getUnscaledValue("v85Bus").setText("nicht ermittelbar");
        data.getUnscaledValue("v85LkwK").setText("nicht ermittelbar");
        data.getUnscaledValue("v85LkwA").setText("nicht ermittelbar");
        data.getUnscaledValue("v85SattelKfz").setText("nicht ermittelbar");
        data.getUnscaledArray("qKfzGeschwKlasse").setLength(0);
        data.getUnscaledArray("qPkwÄGeschwKlasse").setLength(0);
        data.getUnscaledArray("qKfzNkGeschwKlasse").setLength(0);
        data.getUnscaledArray("qPkwGGeschwKlasse").setLength(0);
        data.getUnscaledArray("qPkwGeschwKlasse").setLength(0);
        data.getUnscaledArray("qKradGeschwKlasse").setLength(0);
        data.getUnscaledArray("qLfwGeschwKlasse").setLength(0);
        data.getUnscaledArray("qLkwÄGeschwKlasse").setLength(0);
        data.getUnscaledArray("qPkwAGeschwKlasse").setLength(0);
        data.getUnscaledArray("qLkwGeschwKlasse").setLength(0);
        data.getUnscaledArray("qBusGeschwKlasse").setLength(0);
        data.getUnscaledArray("qLkwKGeschwKlasse").setLength(0);
        data.getUnscaledArray("qLkwAGeschwKlasse").setLength(0);
        data.getUnscaledArray("qSattelKfzGeschwKlasse").setLength(0);

        // Kopiervorlage aller möglichen Werte
        // _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qKfz").set(_qKfz_);
        // _qPkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qPkwÄ").set(_qPkwÄ_);
        // _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
        // _qPkwG_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qPkwG").set(_qPkwG_);
        // _qPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qPkw").set(_qPkw_);
        // _qKrad_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qKrad").set(_qKrad_);
        // _qLfw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qLfw").set(_qLfw_);
        // _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
        // _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qPkwA").set(_qPkwA_);
        // _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qLkw").set(_qLkw_);
        // _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qBus").set(_qBus_);
        // _qLkwK_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qLkwK").set(_qLkwK_);
        // _qLkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qLkwA").set(_qLkwA_);
        // _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qSattelKfz").set(_qSattelKfz_);
        // _vKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vKfz").set(_vKfz_);
        // _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
        // _vKfzNk_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vKfzNk").set(_vKfzNk_);
        // _vPkwG_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vPkwG").set(_vPkwG_);
        // _vPkw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vPkw").set(_vPkw_);
        // _vKrad_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vKrad").set(_vKrad_);
        // _vLfw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vLfw").set(_vLfw_);
        // _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
        // _vPkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vPkwA").set(_vPkwA_);
        // _vLkw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vLkw").set(_vLkw_);
        // _vBus_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vBus").set(_vBus_);
        // _vLkwK_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vLkwK").set(_vLkwK_);
        // _vLkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vLkwA").set(_vLkwA_);
        // _vSattelKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vSattelKfz").set(_vSattelKfz_);
        // _sKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sKfz").set(_sKfz_);
        // _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sPkwÄ").set(_sPkwÄ_);
        // _sKfzNk_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sKfzNk").set(_sKfzNk_);
        // _sPkwG_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sPkwG").set(_sPkwG_);
        // _sPkw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sPkw").set(_sPkw_);
        // _sKrad_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sKrad").set(_sKrad_);
        // _sLfw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sLfw").set(_sLfw_);
        // _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sLkwÄ").set(_sLkwÄ_);
        // _sPkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sPkwA").set(_sPkwA_);
        // _sLkw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sLkw").set(_sLkw_);
        // _sBus_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sBus").set(_sBus_);
        // _sLkwK_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sLkwK").set(_sLkwK_);
        // _sLkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sLkwA").set(_sLkwA_);
        // _sSattelKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sSattelKfz").set(_sSattelKfz_);
        // _v85Kfz_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85Kfz").set(_v85Kfz_);
        // _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85PkwÄ").set(_v85PkwÄ_);
        // _v85KfzNk_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85KfzNk").set(_v85KfzNk_);
        // _v85PkwG_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85PkwG").set(_v85PkwG_);
        // _v85Pkw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85Pkw").set(_v85Pkw_);
        // _v85Krad_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85Krad").set(_v85Krad_);
        // _v85Lfw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85Lfw").set(_v85Lfw_);
        // _v85LkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85LkwÄ").set(_v85LkwÄ_);
        // _v85PkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85PkwA").set(_v85PkwA_);
        // _v85Lkw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85Lkw").set(_v85Lkw_);
        // _v85Bus_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85Bus").set(_v85Bus_);
        // _v85LkwK_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85LkwK").set(_v85LkwK_);
        // _v85LkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85LkwA").set(_v85LkwA_);
        // _v85SattelKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85SattelKfz").set(_v85SattelKfz_);
        // Telegrammabhängig die Daten einlesen, im Telegramm nicht vorhandene Daten auf "nicht ermittelbar" lassen
        switch (deBlock.getTyp()) {
        case 65 :  // Version 10
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);

            break;

        case 66 :  // Version 11
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vKfz").set(_vKfz_);

            break;

        case 67 :  // Version 12
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sPkwÄ").set(_sPkwÄ_);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLkwÄ").set(_sLkwÄ_);

            break;

        case 68 :  // Version 13
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfz").set(_qKfz_);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sPkwÄ").set(_sPkwÄ_);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLkwÄ").set(_sLkwÄ_);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("v85PkwÄ").set(_v85PkwÄ_);

            break;

        case 69 :  // Version 14
            _qPkwG_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwG").set(_qPkwG_);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwA").set(_qPkwA_);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkw").set(_qLkw_);
            _qLkwK_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwK").set(_qLkwK_);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qBus").set(_qBus_);
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfzNk").set(_qKfzNk_);

            break;

        case 70 :  // Version 15
            _qPkwG_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwG").set(_qPkwG_);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwA").set(_qPkwA_);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkw").set(_qLkw_);
            _qLkwK_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwK").set(_qLkwK_);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qBus").set(_qBus_);
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sPkwÄ").set(_sPkwÄ_);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLkwÄ").set(_sLkwÄ_);

            break;

        case 71 :  // Version 16
            _qPkwG_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwG").set(_qPkwG_);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwA").set(_qPkwA_);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkw").set(_qLkw_);
            _qLkwK_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwK").set(_qLkwK_);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qBus").set(_qBus_);
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sPkwÄ").set(_sPkwÄ_);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLkwÄ").set(_sLkwÄ_);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("v85PkwÄ").set(_v85PkwÄ_);

            break;

        case 72 :  // Version 17
            _qPkwG_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwG").set(_qPkwG_);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwA").set(_qPkwA_);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkw").set(_qLkw_);
            _qLkwK_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwK").set(_qLkwK_);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qBus").set(_qBus_);
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sPkwÄ").set(_sPkwÄ_);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLkwÄ").set(_sLkwÄ_);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("v85PkwÄ").set(_v85PkwÄ_);

            // Geschwindigkeitsklassen qPkwÄ einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qPkwÄGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                data.getUnscaledArray("qPkwÄGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qLkwÄ einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qLkwÄGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                data.getUnscaledArray("qLkwÄGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            break;

        case 73 :  // Version 18
            _qPkwG_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwG").set(_qPkwG_);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwA").set(_qPkwA_);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkw").set(_qLkw_);
            _qLkwK_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwK").set(_qLkwK_);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qBus").set(_qBus_);
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
            _vPkwG_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwG").set(_vPkwG_);
            _vPkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwA").set(_vPkwA_);
            _vLkw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkw").set(_vLkw_);
            _vLkwK_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwK").set(_vLkwK_);
            _vBus_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vBus").set(_vBus_);
            _sPkwG_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sPkwG").set(_sPkwG_);
            _sPkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sPkwA").set(_sPkwA_);
            _sLkw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLkw").set(_sLkw_);
            _sLkwK_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLkwK").set(_sLkwK_);
            _sBus_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sBus").set(_sBus_);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("v85PkwÄ").set(_v85PkwÄ_);

            // Geschwindigkeitsklassen qPkwG einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qPkwGGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                data.getUnscaledArray("qPkwGGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qPkwA einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qPkwAGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                data.getUnscaledArray("qPkwAGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qLkw einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qLkwGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                data.getUnscaledArray("qLkwGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qLkwK einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qLkwKGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                data.getUnscaledArray("qLkwKGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qBus einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qBusGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                data.getUnscaledArray("qBusGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            break;

        case 74 :  // Version 19
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
            _qKrad_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKrad").set(_qKrad_);
            _qPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkw").set(_qPkw_);
            _qLfw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLfw").set(_qLfw_);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwA").set(_qPkwA_);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkw").set(_qLkw_);
            _qLkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwA").set(_qLkwA_);
            _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qSattelKfz").set(_qSattelKfz_);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qBus").set(_qBus_);

            break;

        case 75 :  // Version 20
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
            _qKrad_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKrad").set(_qKrad_);
            _qPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkw").set(_qPkw_);
            _qLfw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLfw").set(_qLfw_);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwA").set(_qPkwA_);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkw").set(_qLkw_);
            _qLkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwA").set(_qLkwA_);
            _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qSattelKfz").set(_qSattelKfz_);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qBus").set(_qBus_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sPkwÄ").set(_sPkwÄ_);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLkwÄ").set(_sLkwÄ_);

            break;

        case 76 :  // Version 21
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
            _qKrad_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKrad").set(_qKrad_);
            _qPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkw").set(_qPkw_);
            _qLfw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLfw").set(_qLfw_);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwA").set(_qPkwA_);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkw").set(_qLkw_);
            _qLkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwA").set(_qLkwA_);
            _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qSattelKfz").set(_qSattelKfz_);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qBus").set(_qBus_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sPkwÄ").set(_sPkwÄ_);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLkwÄ").set(_sLkwÄ_);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("v85PkwÄ").set(_v85PkwÄ_);

            break;

        case 77 :  // Version 22
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
            _qKrad_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKrad").set(_qKrad_);
            _qPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkw").set(_qPkw_);
            _qLfw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLfw").set(_qLfw_);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwA").set(_qPkwA_);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkw").set(_qLkw_);
            _qLkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwA").set(_qLkwA_);
            _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qSattelKfz").set(_qSattelKfz_);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qBus").set(_qBus_);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sPkwÄ").set(_sPkwÄ_);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLkwÄ").set(_sLkwÄ_);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("v85PkwÄ").set(_v85PkwÄ_);

            // Geschwindigkeitsklassen qPkwÄ einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qPkwÄGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                data.getUnscaledArray("qPkwÄGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qLkwÄ einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qLkwÄGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                data.getUnscaledArray("qLkwÄGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            break;

        case 78 :  // Version 23
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
            _qKrad_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qKrad").set(_qKrad_);
            _qPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkw").set(_qPkw_);
            _qLfw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLfw").set(_qLfw_);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qPkwA").set(_qPkwA_);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkw").set(_qLkw_);
            _qLkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qLkwA").set(_qLkwA_);
            _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qSattelKfz").set(_qSattelKfz_);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getUnscaledValue("qBus").set(_qBus_);
            _vKrad_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vKrad").set(_vKrad_);
            _vPkw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkw").set(_vPkw_);
            _vLfw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLfw").set(_vLfw_);
            _vPkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vPkwA").set(_vPkwA_);
            _vLkw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkw").set(_vLkw_);
            _vLkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vLkwA").set(_vLkwA_);
            _vSattelKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vSattelKfz").set(_vSattelKfz_);
            _vBus_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("vBus").set(_vBus_);
            _sKrad_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sKrad").set(_sKrad_);
            _sPkw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sPkw").set(_sPkw_);
            _sLfw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLfw").set(_sLfw_);
            _sPkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sPkwA").set(_sPkwA_);
            _sLkw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLkw").set(_sLkw_);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sLkwÄ").set(_sLkwÄ_);
            _sSattelKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sSattelKfz").set(_sSattelKfz_);
            _sBus_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("sBus").set(_sBus_);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledValue("v85PkwÄ").set(_v85PkwÄ_);

            // Inhalt Bytes: Geschwindigkeitsklassen einer Fahrzeugklasse Für jede Geschwindigkeitsklasse wird
            // die Anzahl der Fahrzeuge pro Zeitintervall als vorzeichenloser Wert im Bereich von 0 bis maximal
            // 32767 übertragen.Die Fahrzeugarten werden wie im Anhang 2, Kapitel 2 spezifiziert zusammengefasst.
            // Die Verkehrsstärke wird für Fahrzeugmengen kleiner 128 Fahrzeuge als 1 - Byte - Wert codiert, sonst
            // als 2 - Byte - Wert. Die Kennzeichnung erfolgt im 7. Bit des 1. Bytes(low Byte) eines
            // Verkehrsstärkewertes. Ist dieses gesetzt(1), so ist die Verkehrsstärke als 1 - Byte - Wert
            // codiert und die Anzahl Fahrzeuge ermittelt sich als Byte1  128. Ist das Bit nicht gesetzt, so ist die
            // Verkehrsstärke als 2 - Byte - Wert codiert und ermittelt sich als Byte1 + Byte2 * 128. Die Sonderregelung
            // zur Codierung der Fahrzeugmengen verhindert, dass der DE -Block insgesamt zu lang wird.
            // Geschwindigkeitsklassen qKrad einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qKradGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                data.getUnscaledArray("qKradGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qPkw einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qPkwGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                data.getUnscaledArray("qPkwGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qLfw einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qLfwGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                data.getUnscaledArray("qLfwGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qPkwA einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qPkwAGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                data.getUnscaledArray("qPkwAGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qLkw einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qLkwGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                data.getUnscaledArray("qLkwGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qLkwA einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qLkwAGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                data.getUnscaledArray("qLkwAGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qSattelKfz einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qSattelKfzGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                data.getUnscaledArray("qSattelKfzGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            // Geschwindigkeitsklassen qBus einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            data.getUnscaledArray("qBusGeschwKlasse").setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                data.getUnscaledArray("qBusGeschwKlasse").getValue(i).set(_qKlasse_);
            }

            break;

        default :
            debug.warning("Unbekannter LVE-Langzeittyp-Typ (10 - 23): " + deBlock.getTyp());
        }

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    /**
     * Verarbeitet die Telegrammversion 24 der TLS (Typ 79 - Geschwindigkeitsdaten). Genaue Beschreibung bzg. Aufbau der
     * Telegramme in den einzelnen Versionen siehe TLS.
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    private ResultData TlsLveErgebnisMeldungVersion24AspTlsAntwort(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Mehrfachverarbeitung (zur Sicherheit den Lesezeiger nochmal zurücksetzen)
        deBlock.getDeData().rewindReadPosition();

        // Intervalllänge aus IntervalldatenHeader ---------------------------------------------------------------------
        data.getTimeValue("T").setSeconds(_eakConversionModul.getLveIntervalDuration());

        // Alle Werte mit Zustand "nicht ermittelbar" initialisieren.
        for (String fzName : new String[] { "KfzNk", "Krad", "Pkw", "Lfw", "PkwA", "Lkw", "LkwA", "SattelKfz", "Bus" }) {
            data.getUnscaledValue("q" + fzName).setText("nicht ermittelbar");
        }

        for (String fzName : new String[] { "LVo", "SGV", "BPA" }) {
            data.getUnscaledValue("v" + fzName).setText("nicht ermittelbar");
            data.getUnscaledValue("s" + fzName).setText("nicht ermittelbar");
            data.getUnscaledValue("v85" + fzName).setText("nicht ermittelbar");
            data.getUnscaledValue("v15" + fzName).setText("nicht ermittelbar");
            data.getUnscaledArray("q" + fzName + "GeschwKlasse").setLength(0);
        }

        if (deBlock.getTyp() == 79) {

            // TLS-Rohdaten aus DE-Block holen
            int   _qKfzNk_     = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qKrad_      = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qPkw_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qLfw_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qPkwA_      = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qLkw_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qLkwA_      = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _qBus_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _vLVo_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _vSGV_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _vBPA_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _sLVo_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _sSGV_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _sBPA_       = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            int   _v85LVo_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v85SGV_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v85BPA_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v15LVo_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v15SGV_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _v15BPA_     = deBlock.getDeData().readUnsignedByteAsInt();
            int   _countLVo_   = deBlock.getDeData().readUnsignedByteAsInt();
            int[] _qKlasseLVo_ = new int[_countLVo_];

            for (int i = 0; i < _countLVo_; i++) {
                _qKlasseLVo_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            int   _countSGV_   = deBlock.getDeData().readUnsignedByteAsInt();
            int[] _qKlasseSGV_ = new int[_countSGV_];

            for (int i = 0; i < _countSGV_; i++) {
                _qKlasseSGV_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            int   _countBPA_   = deBlock.getDeData().readUnsignedByteAsInt();
            int[] _qKlasseBPA_ = new int[_countBPA_];

            for (int i = 0; i < _countBPA_; i++) {
                _qKlasseBPA_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            // Daten an ATG (Version 24) zuweisen
            data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
            data.getUnscaledValue("qKrad").set(_qKrad_);
            data.getUnscaledValue("qPkw").set(_qPkw_);
            data.getUnscaledValue("qLfw").set(_qLfw_);
            data.getUnscaledValue("qPkwA").set(_qPkwA_);
            data.getUnscaledValue("qLkw").set(_qLkw_);
            data.getUnscaledValue("qLkwA").set(_qLkwA_);
            data.getUnscaledValue("qSattelKfz").set(_qSattelKfz_);
            data.getUnscaledValue("qBus").set(_qBus_);
            data.getUnscaledValue("vLVo").set(tls16BitTo16BitInt(_vLVo_));
            data.getUnscaledValue("vSGV").set(tls16BitTo16BitInt(_vSGV_));
            data.getUnscaledValue("vBPA").set(tls16BitTo16BitInt(_vBPA_));
            data.getUnscaledValue("sLVo").set(tls16BitTo16BitInt(_sLVo_));
            data.getUnscaledValue("sSGV").set(tls16BitTo16BitInt(_sSGV_));
            data.getUnscaledValue("sBPA").set(tls16BitTo16BitInt(_sBPA_));
            data.getUnscaledValue("v85LVo").set(_v85LVo_);
            data.getUnscaledValue("v85SGV").set(_v85SGV_);
            data.getUnscaledValue("v85BPA").set(_v85BPA_);
            data.getUnscaledValue("v15LVo").set(_v15LVo_);
            data.getUnscaledValue("v15SGV").set(_v15SGV_);
            data.getUnscaledValue("v15BPA").set(_v15BPA_);
            data.getUnscaledArray("qLVoGeschwKlasse").setLength(_countLVo_);

            for (int i = 0; i < _countLVo_; i++) {
                data.getUnscaledArray("qLVoGeschwKlasse").getValue(i).set(_qKlasseLVo_[i]);
            }

            data.getUnscaledArray("qSGVGeschwKlasse").setLength(_countSGV_);

            for (int i = 0; i < _countSGV_; i++) {
                data.getUnscaledArray("qSGVGeschwKlasse").getValue(i).set(_qKlasseSGV_[i]);
            }

            data.getUnscaledArray("qBPAGeschwKlasse").setLength(_countBPA_);

            for (int i = 0; i < _countBPA_; i++) {
                data.getUnscaledArray("qBPAGeschwKlasse").getValue(i).set(_qKlasseBPA_[i]);
            }
        } else {
            debug.warning("Nicht erlaubter LVE-Langzeittyp-Typ: " + deBlock.getTyp());
        }

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    /**
     * Verarbeitet alls Telegrammversionen der TLS Kurzeit Version 0-4 (Typ 49/113 -53/117).
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    private ResultData VerkehrsDatenKurzGeschwindigkeitsKlassenZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Intervalllänge aus IntervalldatenHeader ---------------------------------------------------------------------
        data.getTimeValue("T").setSeconds(_eakConversionModul.getLveIntervalDuration());

        int        _qKfz_;               // qKfz-Wert aus Telegramm
        int        _qLkwÄ_;              // qLkw-Wert aus Telegramm
        int        _vPkwÄ_;              // qPkwÄ-Wert aus Telegramm
        int        _vLkwÄ_;              // vLkwÄ-Wert aus Telegramm
        int        _tNetto_;             // tNetto-Wert aus Telegramm
        int        _b_;                  // Belegungs-Wert aus Telegramm
        int        _sKfz_;               // Streuung Kfz-Wert aus Telegramm
        int        _vgKfz_;              // vgKfz-Wert aus Telegramm
        int        countQPkwÄGeschwKlasse = 0;
        int[]      _qPkwÄGeschwKlasse_;  // Geschwindigkeitsklasse qPkwÄ-Werte aus Telegramm
        int        countQLkwÄGeschwKlasse = 0;
        int[]      _qLkwÄGeschwKlasse_;  // Geschwindigkeitsklasse qLkwÄ-Wertte aus Telegramm
        Data.Array _KlassePkw_;
        Data.Array _KlasseLkw_;

        // Werte jeweils auf Zustand "nicht ermittelbar" setzen.
        String[] valStrings = { "qKfz", "vKfz", "qLkw", "vLkw", "qPkw", "vPkw", "b", "tNetto", "sKfz", "vgKfz" };

        // Telegrammabhängig die Daten einlesen, im Telegramm nicht vorhandene Daten auf "nicht ermittelbar" lassen
        switch (deBlock.getTyp()) {
        case 53 :  // Version 4 - 8-Bit-Format

            /* Werte lesen und ignorieren */
            _qKfz_   = deBlock.getDeData().readUnsignedByteAsInt();
            _qLkwÄ_  = deBlock.getDeData().readUnsignedByteAsInt();
            _vPkwÄ_  = deBlock.getDeData().readUnsignedByteAsInt();
            _vLkwÄ_  = deBlock.getDeData().readUnsignedByteAsInt();
            _tNetto_ = deBlock.getDeData().readUnsignedByteAsInt() * 100;  // Umrechnung in Millisekunden;
            _b_      = deBlock.getDeData().readUnsignedByteAsInt();

            if (_b_ != 255) {
                if (_b_ > 100) {
                    debug.warning("Belegung von " + _b_ + "% > 100% erhalten! Wert wurde auf 'nicht ermittelbar' geändert!");
                } else {}
            }

            _sKfz_  = deBlock.getDeData().readUnsignedByteAsInt();
            _vgKfz_ = deBlock.getDeData().readUnsignedByteAsInt();

            // Geschwindigkeitsklassen qPkwÄ einlesen
            countQPkwÄGeschwKlasse = deBlock.getDeData().readUnsignedByteAsInt();
            _qPkwÄGeschwKlasse_    = new int[countQPkwÄGeschwKlasse];

            for (int i = 0; i < countQPkwÄGeschwKlasse; i++) {
                _qPkwÄGeschwKlasse_[i] = deBlock.getDeData().readUnsignedByteAsInt();
            }

            _KlassePkw_ = data.getArray("qPkwÄGeschwKlasse");
            _KlassePkw_.setLength(countQPkwÄGeschwKlasse);

            for (int i = 0; i < countQPkwÄGeschwKlasse; i++) {
                _KlassePkw_.getItem(i).getUnscaledValue("Wert").set(tls8BitToInt(_qPkwÄGeschwKlasse_[i]));
                _KlassePkw_.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                _KlassePkw_.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qLkwÄ einlesen
            countQLkwÄGeschwKlasse = deBlock.getDeData().readUnsignedByteAsInt();
            _qLkwÄGeschwKlasse_    = new int[countQLkwÄGeschwKlasse];

            for (int i = 0; i < countQLkwÄGeschwKlasse; i++) {
                _qLkwÄGeschwKlasse_[i] = deBlock.getDeData().readUnsignedByteAsInt();
            }

            _KlasseLkw_ = data.getArray("qLkwÄGeschwKlasse");
            _KlasseLkw_.setLength(countQLkwÄGeschwKlasse);

            for (int i = 0; i < countQLkwÄGeschwKlasse; i++) {
                _KlasseLkw_.getItem(i).getUnscaledValue("Wert").set(tls8BitToInt(_qLkwÄGeschwKlasse_[i]));
                _KlasseLkw_.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                _KlasseLkw_.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            break;

        case 117 :                                                         // Version 4 - 16-Bit-Format
            _qKfz_   = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            _qLkwÄ_  = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            _vPkwÄ_  = deBlock.getDeData().readUnsignedByteAsInt();
            _vLkwÄ_  = deBlock.getDeData().readUnsignedByteAsInt();
            _tNetto_ = deBlock.getDeData().readUnsignedByteAsInt() * 100;  // Umrechnung in Millisekunden;
            _b_      = deBlock.getDeData().readUnsignedByteAsInt();
            _sKfz_   = deBlock.getDeData().readUnsignedByteAsInt();
            _vgKfz_  = deBlock.getDeData().readUnsignedByteAsInt();

            // Geschwindigkeitsklassen qPkwÄ einlesen
            countQPkwÄGeschwKlasse = deBlock.getDeData().readUnsignedByteAsInt();
            _qPkwÄGeschwKlasse_    = new int[countQPkwÄGeschwKlasse];

            for (int i = 0; i < countQPkwÄGeschwKlasse; i++) {
                _qPkwÄGeschwKlasse_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            _KlassePkw_ = data.getArray("qPkwÄGeschwKlasse");
            _KlassePkw_.setLength(countQPkwÄGeschwKlasse);

            for (int i = 0; i < countQPkwÄGeschwKlasse; i++) {
                _KlassePkw_.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qPkwÄGeschwKlasse_[i]));
                _KlassePkw_.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                _KlassePkw_.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                _KlassePkw_.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qPkwÄ einlesen
            countQLkwÄGeschwKlasse = deBlock.getDeData().readUnsignedByteAsInt();
            _qLkwÄGeschwKlasse_    = new int[countQLkwÄGeschwKlasse];

            for (int i = 0; i < countQLkwÄGeschwKlasse; i++) {
                _qLkwÄGeschwKlasse_[i] = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            }

            _KlasseLkw_ = data.getArray("qLkwÄGeschwKlasse");
            _KlasseLkw_.setLength(countQLkwÄGeschwKlasse);

            for (int i = 0; i < countQLkwÄGeschwKlasse; i++) {
                _KlasseLkw_.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qLkwÄGeschwKlasse_[i]));
                _KlasseLkw_.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                _KlasseLkw_.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                _KlasseLkw_.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            break;

        default :
            debug.warning("Unbekannter LVE-Kurzzeit-Typ (49/113 - 53/117): " + deBlock.getTyp());
        }

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    /**
     * Verarbeitet alls Telegrammversionen der TLS Kurzeit Version 0-4 (Typ 49/113 -53/117).
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    ResultData VerkehrsDatenKurzZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {

        // Die Ausführung von Umsetzungsmethoden kann zur Laufzeit über den
        // Parameter atg.tlsPassivierungÜbernahmeLogischesModell am typ.de
        // unterbunden werden, in dem der Zustand des Parameters ausgewertet
        // und bei Passivierung als return-Wert null zurückgegeben wird
        if (isPassivierungUmsetzungsMethoden()) {
            return null;
        }

        // Intervalllänge aus IntervalldatenHeader ---------------------------------------------------------------------
        data.getTimeValue("T").setSeconds(_eakConversionModul.getLveIntervalDuration());

        // Art der Mittelwertbildung am DE aus Betriebsparametern ------------------------------------------------------
        switch (_kindOfAverage) {
        case 0 :
            data.getUnscaledValue("ArtMittelwertbildung").setText("gleitende Mittelwertbildung");

            break;

        case 1 :
            data.getUnscaledValue("ArtMittelwertbildung").setText("arithmetische Mittelwertbildung");

            break;

        default :
            data.getUnscaledValue("ArtMittelwertbildung").setText("unbekannt");
        }

        // Messwerte aus dem DE-Block extrahieren...
        Fg001VerkehrsDaten fg001VerkehrsDaten = new Fg001VerkehrsDaten(deBlock, _de.getDePid());

        // ...und die PL-Prüfung/Korrektur gemäß AFo-DUA, Anforderung KEx-15 durchführen...
        fg001VerkehrsDaten.plPruefungUndKorrektur();

        // ...und die geprüften/koorigierten Daten der ATG mit den Werten aus dem DE-Block setzen
        data = fg001VerkehrsDaten.ermittleDatenAtgVerkehrsDatenKurzZeitIntervallAspExterneErfassung(data);

        // DE-Daten-Ausfallüberwachung aufrufen und nächsten Zeitpunkt eintragen, an dem spätesten KEINE DATEN gesendet wird.
        DeAusfallUeberwachung.addAuftrag(_config, _de, dataDescription, "typ.fahrStreifen", _eakConversionModul.getTimeStamp(), _eakConversionModul.getLveIntervalDuration());

        // Betriebsmeldung absetzen, falls vorhanden
        try {
            if (!fg001VerkehrsDaten.getBetriebsMeldung().equals("")) {
                sendMessage(_de.getDe().getNameOrPidOrId(), MessageType.APPLICATION_DOMAIN, "[KEx-BD-VW01]", MessageGrade.INFORMATION, _de.getDe(), MessageState.MESSAGE, fg001VerkehrsDaten.getBetriebsMeldung());
            }
        }
        catch (Exception e) {
            debug.warning("Betriebsmeldung konnte nicht verschickt werden" + fg001VerkehrsDaten.getBetriebsMeldung(), e);
        }

        // Ergebnisdatensatz erzeugen...
        ResultData resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }

    /**
     * Verarbeitet alle Telegrammversionen der TLS Langzeitversionden Version 0-4 (Typ 65 -96).
     *
     * @param deBlock         Der zu bearbeitende De-Block.
     * @param data            Der passende Datensatz für die Ziel Attributgruppe/Aspekt-Kombination.
     * @param dataDescription Die Datenbeschreibung für die Attributgruppe/Aspekt-Kombination.
     *
     * @return Ergebnisdatensatz mit den vom DeBlock in die entsprechende Attributgruppe konvertierten Daten.
     */
    private ResultData VerkehrsDatenLangZeitIntervallAspExterneErfassung(DeBlock deBlock, Data data, DataDescription dataDescription) {
        ResultData resultData = null;

        // Intervalllänge aus IntervalldatenHeader ---------------------------------------------------------------------
        data.getTimeValue("T").setSeconds(_eakConversionModul.getLveIntervalDuration());

        int        _qKfz_;
        int        _qPkwÄ_;         // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _qKfzNk_;
        int        _qPkwG_;
        int        _qPkw_;
        int        _qKrad_;
        int        _qLfw_;
        int        _qLkwÄ_;
        int        _qPkwA_;
        int        _qLkw_;
        int        _qBus_;
        int        _qLkwK_;
        int        _qLkwA_;
        int        _qSattelKfz_;
        int        _vKfz_;
        int        _vPkwÄ_;
        int        _vKfzNk_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _vPkwG_;
        int        _vPkw_;
        int        _vKrad_;
        int        _vLfw_;
        int        _vLkwÄ_;
        int        _vPkwA_;
        int        _vLkw_;
        int        _vBus_;
        int        _vLkwK_;
        int        _vLkwA_;
        int        _vSattelKfz_;
        int        _sKfz_;          // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _sPkwÄ_;
        int        _sKfzNk_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _sPkwG_;
        int        _sPkw_;
        int        _sKrad_;
        int        _sLfw_;
        int        _sLkwÄ_;
        int        _sPkwA_;
        int        _sLkw_;
        int        _sBus_;
        int        _sLkwK_;
        int        _sLkwA_;         // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _sSattelKfz_;
        int        _v85Kfz_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _v85PkwÄ_;
        int        _v85KfzNk_;      // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _v85PkwG_;       // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _v85Pkw_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _v85Krad_;       // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _v85Lfw_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _v85LkwÄ_;       // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _v85PkwA_;       // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _v85Lkw_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _v85Bus_;        // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _v85LkwK_;       // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _v85LkwA_;       // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        _v85SattelKfz_;  // für Erweiterungen aus Gründen der Systematik mit aufgenommen.
        int        count = 0;
        int        _qKlasse_;
        Data.Array array = null;

        // Werte jeweils auf Zustand "nicht ermittelbar" setzen.
        String[] valStrings = { "qKfz", "qPkwÄ", "qKfzNk", "qPkwG", "qPkw", "qKrad", "qLfw", "qLkwÄ", "qPkwA", "qLkw", "qBus", "qLkwK", "qLkwA", "qSattelKfz", "vKfz", "vPkwÄ", "vKfzNk", "vPkwG", "vPkw", "vKrad", "vLfw", "vLkwÄ", "vPkwA", "vLkw", "vBus", "vLkwK", "vLkwA", "vSattelKfz", "sKfz", "sPkwÄ", "sKfzNk", "sPkwG", "sPkw", "sKrad", "sLfw", "sLkwÄ", "sPkwA", "sLkw", "sBus", "sLkwK", "sLkwA", "sSattelKfz", "v85Kfz", "v85PkwÄ", "v85KfzNk", "v85PkwG", "v85Pkw", "v85Krad", "v85Lfw", "v85LkwÄ",
                                "v85PkwA", "v85Lkw", "v85Bus", "v85LkwK", "v85LkwA", "v85SattelKfz" };

        for (int idx = 0; idx < valStrings.length; idx++) {
            data.getItem(valStrings[idx]).getUnscaledValue("Wert").setText("nicht ermittelbar");
            data.getItem(valStrings[idx]).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
            data.getItem(valStrings[idx]).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
            data.getItem(valStrings[idx]).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
            data.getItem(valStrings[idx]).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
            data.getItem(valStrings[idx]).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
            data.getItem(valStrings[idx]).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
            data.getItem(valStrings[idx]).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
            data.getItem(valStrings[idx]).getItem("Güte").getUnscaledValue("Index").set(-1);
            data.getItem(valStrings[idx]).getItem("Güte").getUnscaledValue("Verfahren").set(0);
        }

        data.getArray("qKfzGeschwKlasse").setLength(0);
        data.getArray("qPkwÄGeschwKlasse").setLength(0);
        data.getArray("qKfzNkGeschwKlasse").setLength(0);
        data.getArray("qPkwGGeschwKlasse").setLength(0);
        data.getArray("qPkwGeschwKlasse").setLength(0);
        data.getArray("qKradGeschwKlasse").setLength(0);
        data.getArray("qLfwGeschwKlasse").setLength(0);
        data.getArray("qLkwÄGeschwKlasse").setLength(0);
        data.getArray("qPkwAGeschwKlasse").setLength(0);
        data.getArray("qLkwGeschwKlasse").setLength(0);
        data.getArray("qBusGeschwKlasse").setLength(0);
        data.getArray("qLkwKGeschwKlasse").setLength(0);
        data.getArray("qLkwAGeschwKlasse").setLength(0);
        data.getArray("qSattelKfzGeschwKlasse").setLength(0);

        // Kopiervorlage aller möglichen Werte
        // _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qKfz").set(_qKfz_);
        // _qPkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qPkwÄ").set(_qPkwÄ_);
        // _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qKfzNk").set(_qKfzNk_);
        // _qPkwG_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qPkwG").set(_qPkwG_);
        // _qPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qPkw").set(_qPkw_);
        // _qKrad_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qKrad").set(_qKrad_);
        // _qLfw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qLfw").set(_qLfw_);
        // _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qLkwÄ").set(_qLkwÄ_);
        // _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qPkwA").set(_qPkwA_);
        // _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qLkw").set(_qLkw_);
        // _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qBus").set(_qBus_);
        // _qLkwK_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qLkwK").set(_qLkwK_);
        // _qLkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qLkwA").set(_qLkwA_);
        // _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
        // data.getUnscaledValue("qSattelKfz").set(_qSattelKfz_);
        // _vKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vKfz").set(_vKfz_);
        // _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vPkwÄ").set(_vPkwÄ_);
        // _vKfzNk_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vKfzNk").set(_vKfzNk_);
        // _vPkwG_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vPkwG").set(_vPkwG_);
        // _vPkw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vPkw").set(_vPkw_);
        // _vKrad_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vKrad").set(_vKrad_);
        // _vLfw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vLfw").set(_vLfw_);
        // _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vLkwÄ").set(_vLkwÄ_);
        // _vPkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vPkwA").set(_vPkwA_);
        // _vLkw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vLkw").set(_vLkw_);
        // _vBus_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vBus").set(_vBus_);
        // _vLkwK_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vLkwK").set(_vLkwK_);
        // _vLkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vLkwA").set(_vLkwA_);
        // _vSattelKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("vSattelKfz").set(_vSattelKfz_);
        // _sKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sKfz").set(_sKfz_);
        // _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sPkwÄ").set(_sPkwÄ_);
        // _sKfzNk_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sKfzNk").set(_sKfzNk_);
        // _sPkwG_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sPkwG").set(_sPkwG_);
        // _sPkw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sPkw").set(_sPkw_);
        // _sKrad_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sKrad").set(_sKrad_);
        // _sLfw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sLfw").set(_sLfw_);
        // _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sLkwÄ").set(_sLkwÄ_);
        // _sPkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sPkwA").set(_sPkwA_);
        // _sLkw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sLkw").set(_sLkw_);
        // _sBus_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sBus").set(_sBus_);
        // _sLkwK_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sLkwK").set(_sLkwK_);
        // _sLkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sLkwA").set(_sLkwA_);
        // _sSattelKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("sSattelKfz").set(_sSattelKfz_);
        // _v85Kfz_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85Kfz").set(_v85Kfz_);
        // _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85PkwÄ").set(_v85PkwÄ_);
        // _v85KfzNk_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85KfzNk").set(_v85KfzNk_);
        // _v85PkwG_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85PkwG").set(_v85PkwG_);
        // _v85Pkw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85Pkw").set(_v85Pkw_);
        // _v85Krad_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85Krad").set(_v85Krad_);
        // _v85Lfw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85Lfw").set(_v85Lfw_);
        // _v85LkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85LkwÄ").set(_v85LkwÄ_);
        // _v85PkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85PkwA").set(_v85PkwA_);
        // _v85Lkw_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85Lkw").set(_v85Lkw_);
        // _v85Bus_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85Bus").set(_v85Bus_);
        // _v85LkwK_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85LkwK").set(_v85LkwK_);
        // _v85LkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85LkwA").set(_v85LkwA_);
        // _v85SattelKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
        // data.getUnscaledValue("v85SattelKfz").set(_v85SattelKfz_);
        // Telegrammabhängig die Daten einlesen, im Telegramm nicht vorhandene Daten auf "nicht ermittelbar" lassen
        switch (deBlock.getTyp()) {
        case 65 :  // Version 10
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfz").getUnscaledValue("Wert").set(tls16BitToInt(_qKfz_));
            data.getItem("qKfz").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwÄ").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwÄ_));
            data.getItem("qLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);

            break;

        case 66 :  // Version 11
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfz").getUnscaledValue("Wert").set(tls16BitToInt(_qKfz_));
            data.getItem("qKfz").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwÄ").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwÄ_));
            data.getItem("qLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _vKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vKfz").getUnscaledValue("Wert").set(tls8BitToInt(_vKfz_));
            data.getItem("vKfz").getItem("Güte").getScaledValue("Index").set(1.0);

            break;

        case 67 :  // Version 12
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfz").getUnscaledValue("Wert").set(tls16BitToInt(_qKfz_));
            data.getItem("qKfz").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwÄ").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwÄ_));
            data.getItem("qLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vPkwÄ_));
            data.getItem("vPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vLkwÄ_));
            data.getItem("vLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sPkwÄ_));
            data.getItem("sPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sLkwÄ_));
            data.getItem("sLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);

            break;

        case 68 :  // Version 13
            _qKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfz").getUnscaledValue("Wert").set(tls16BitToInt(_qKfz_));
            data.getItem("qKfz").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwÄ_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwÄ").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwÄ_));
            data.getItem("qLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vPkwÄ_));
            data.getItem("vPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vLkwÄ_));
            data.getItem("vLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sPkwÄ_));
            data.getItem("sPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sLkwÄ_));
            data.getItem("sLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("v85PkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_v85PkwÄ_));
            data.getItem("v85PkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);

            break;

        case 69 :  // Version 14
            _qPkwG_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwG").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwG_));
            data.getItem("qPkwG").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwA_));
            data.getItem("qPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkw").getUnscaledValue("Wert").set(tls16BitToInt(_qLkw_));
            data.getItem("qLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwK_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwK").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwK_));
            data.getItem("qLkwK").getItem("Güte").getScaledValue("Index").set(1.0);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qBus").getUnscaledValue("Wert").set(tls16BitToInt(_qBus_));
            data.getItem("qBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfzNk").getUnscaledValue("Wert").set(tls16BitToInt(_qKfzNk_));
            data.getItem("qKfzNk").getItem("Güte").getScaledValue("Index").set(1.0);

            break;

        case 70 :  // Version 15
            _qPkwG_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwG").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwG_));
            data.getItem("qPkwG").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwA_));
            data.getItem("qPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkw").getUnscaledValue("Wert").set(tls16BitToInt(_qLkw_));
            data.getItem("qLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwK_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwK").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwK_));
            data.getItem("qLkwK").getItem("Güte").getScaledValue("Index").set(1.0);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qBus").getUnscaledValue("Wert").set(tls16BitToInt(_qBus_));
            data.getItem("qBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfzNk").getUnscaledValue("Wert").set(tls16BitToInt(_qKfzNk_));
            data.getItem("qKfzNk").getItem("Güte").getScaledValue("Index").set(1.0);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vPkwÄ_));
            data.getItem("vPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vLkwÄ_));
            data.getItem("vLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sPkwÄ_));
            data.getItem("sPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sLkwÄ_));
            data.getItem("sLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);

            break;

        case 71 :  // Version 16
            _qPkwG_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwG").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwG_));
            data.getItem("qPkwG").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwA_));
            data.getItem("qPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkw").getUnscaledValue("Wert").set(tls16BitToInt(_qLkw_));
            data.getItem("qLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwK_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwK").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwK_));
            data.getItem("qLkwK").getItem("Güte").getScaledValue("Index").set(1.0);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qBus").getUnscaledValue("Wert").set(tls16BitToInt(_qBus_));
            data.getItem("qBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfzNk").getUnscaledValue("Wert").set(tls16BitToInt(_qKfzNk_));
            data.getItem("qKfzNk").getItem("Güte").getScaledValue("Index").set(1.0);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vPkwÄ_));
            data.getItem("vPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vLkwÄ_));
            data.getItem("vLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sPkwÄ_));
            data.getItem("sPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sLkwÄ_));
            data.getItem("sLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("v85PkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_v85PkwÄ_));
            data.getItem("v85PkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);

            break;

        case 72 :  // Version 17
            _qPkwG_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwG").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwG_));
            data.getItem("qPkwG").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwA_));
            data.getItem("qPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkw").getUnscaledValue("Wert").set(tls16BitToInt(_qLkw_));
            data.getItem("qLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwK_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwK").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwK_));
            data.getItem("qLkwK").getItem("Güte").getScaledValue("Index").set(1.0);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qBus").getUnscaledValue("Wert").set(tls16BitToInt(_qBus_));
            data.getItem("qBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfzNk").getUnscaledValue("Wert").set(tls16BitToInt(_qKfzNk_));
            data.getItem("qKfzNk").getItem("Güte").getScaledValue("Index").set(1.0);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vPkwÄ_));
            data.getItem("vPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vLkwÄ_));
            data.getItem("vLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sPkwÄ_));
            data.getItem("sPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sLkwÄ_));
            data.getItem("sLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("v85PkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_v85PkwÄ_));
            data.getItem("v85PkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);

            // Geschwindigkeitsklassen qPkwÄ einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qPkwÄGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qLkwÄ einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qLkwÄGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            break;

        case 73 :                                                                         // Version 18
            _qPkwG_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwG").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwG_));
            data.getItem("qPkwG").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwA_));
            data.getItem("qPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkw").getUnscaledValue("Wert").set(tls16BitToInt(_qLkw_));
            data.getItem("qLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwK_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwK").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwK_));
            data.getItem("qLkwK").getItem("Güte").getScaledValue("Index").set(1.0);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qBus").getUnscaledValue("Wert").set(tls16BitToInt(_qBus_));
            data.getItem("qBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfzNk").getUnscaledValue("Wert").set(tls16BitToInt(_qKfzNk_));
            data.getItem("qKfzNk").getItem("Güte").getScaledValue("Index").set(1.0);
            _vPkwG_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vPkwG").getUnscaledValue("Wert").set(tls8BitToInt(_vPkwG_));
            data.getItem("vPkwG").getItem("Güte").getScaledValue("Index").set(1.0);
            _vPkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vPkwA").getUnscaledValue("Wert").set(tls8BitToInt(_vPkwA_));
            data.getItem("vPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLkw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLkw").getUnscaledValue("Wert").set(tls8BitToInt(_vLkw_));
            data.getItem("vLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLkwK_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLkwK").getUnscaledValue("Wert").set(tls8BitToInt(_vLkwK_));
            data.getItem("vLkwK").getItem("Güte").getScaledValue("Index").set(1.0);
            _vBus_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vBus").getUnscaledValue("Wert").set(tls8BitToInt(_vBus_));
            data.getItem("vBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _sPkwG_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sPkwG").getUnscaledValue("Wert").set(tls8BitToInt(_sPkwG_));
            data.getItem("sPkwG").getItem("Güte").getScaledValue("Index").set(1.0);
            _sPkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sPkwA").getUnscaledValue("Wert").set(tls8BitToInt(_sPkwA_));
            data.getItem("sPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLkw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLkw").getUnscaledValue("Wert").set(tls8BitToInt(_sLkw_));
            data.getItem("sLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLkwK_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLkwK").getUnscaledValue("Wert").set(tls8BitToInt(_sLkwK_));
            data.getItem("sLkwK").getItem("Güte").getScaledValue("Index").set(1.0);
            _sBus_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sBus").getUnscaledValue("Wert").set(tls8BitToInt(_sBus_));
            data.getItem("sBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("v85PkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_v85PkwÄ_));
            data.getItem("v85PkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);

            // Geschwindigkeitsklassen qPkwG einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qPkwGGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qPkwA einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qPkwAGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qLkw einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qLkwGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qLkwK einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qLkwKGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qBus einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qBusGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            break;

        case 74 :                                                                         // Version 19
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfzNk").getUnscaledValue("Wert").set(tls16BitToInt(_qKfzNk_));
            data.getItem("qKfzNk").getItem("Güte").getScaledValue("Index").set(1.0);
            _qKrad_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKrad").getUnscaledValue("Wert").set(tls16BitToInt(_qKrad_));
            data.getItem("qKrad").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkw").getUnscaledValue("Wert").set(tls16BitToInt(_qPkw_));
            data.getItem("qPkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLfw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLfw").getUnscaledValue("Wert").set(tls16BitToInt(_qLfw_));
            data.getItem("qLfw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwA_));
            data.getItem("qPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkw").getUnscaledValue("Wert").set(tls16BitToInt(_qLkw_));
            data.getItem("qLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwA_));
            data.getItem("qLkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qSattelKfz").getUnscaledValue("Wert").set(tls16BitToInt(_qSattelKfz_));
            data.getItem("qSattelKfz").getItem("Güte").getScaledValue("Index").set(1.0);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qBus").getUnscaledValue("Wert").set(tls16BitToInt(_qBus_));
            data.getItem("qBus").getItem("Güte").getScaledValue("Index").set(1.0);

            break;

        case 75 :                                                                         // Version 20
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfzNk").getUnscaledValue("Wert").set(tls16BitToInt(_qKfzNk_));
            data.getItem("qKfzNk").getItem("Güte").getScaledValue("Index").set(1.0);
            _qKrad_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKrad").getUnscaledValue("Wert").set(tls16BitToInt(_qKrad_));
            data.getItem("qKrad").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkw").getUnscaledValue("Wert").set(tls16BitToInt(_qPkw_));
            data.getItem("qPkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLfw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLfw").getUnscaledValue("Wert").set(tls16BitToInt(_qLfw_));
            data.getItem("qLfw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwA_));
            data.getItem("qPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkw").getUnscaledValue("Wert").set(tls16BitToInt(_qLkw_));
            data.getItem("qLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwA_));
            data.getItem("qLkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qSattelKfz").getUnscaledValue("Wert").set(tls16BitToInt(_qSattelKfz_));
            data.getItem("qSattelKfz").getItem("Güte").getScaledValue("Index").set(1.0);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qBus").getUnscaledValue("Wert").set(tls16BitToInt(_qBus_));
            data.getItem("qBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vPkwÄ_));
            data.getItem("vPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vLkwÄ_));
            data.getItem("vLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sPkwÄ_));
            data.getItem("sPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sLkwÄ_));
            data.getItem("sLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);

            break;

        case 76 :                                                                         // Version 21
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfzNk").getUnscaledValue("Wert").set(tls16BitToInt(_qKfzNk_));
            data.getItem("qKfzNk").getItem("Güte").getScaledValue("Index").set(1.0);
            _qKrad_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKrad").getUnscaledValue("Wert").set(tls16BitToInt(_qKrad_));
            data.getItem("qKrad").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkw").getUnscaledValue("Wert").set(tls16BitToInt(_qPkw_));
            data.getItem("qPkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLfw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLfw").getUnscaledValue("Wert").set(tls16BitToInt(_qLfw_));
            data.getItem("qLfw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwA_));
            data.getItem("qPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkw").getUnscaledValue("Wert").set(tls16BitToInt(_qLkw_));
            data.getItem("qLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwA_));
            data.getItem("qLkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qSattelKfz").getUnscaledValue("Wert").set(tls16BitToInt(_qSattelKfz_));
            data.getItem("qSattelKfz").getItem("Güte").getScaledValue("Index").set(1.0);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qBus").getUnscaledValue("Wert").set(tls16BitToInt(_qBus_));
            data.getItem("qBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vPkwÄ_));
            data.getItem("vPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vLkwÄ_));
            data.getItem("vLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sPkwÄ_));
            data.getItem("sPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sLkwÄ_));
            data.getItem("sLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("v85PkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_v85PkwÄ_));
            data.getItem("v85PkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);

            break;

        case 77 :                                                                         // Version 22
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfzNk").getUnscaledValue("Wert").set(tls16BitToInt(_qKfzNk_));
            data.getItem("qKfzNk").getItem("Güte").getScaledValue("Index").set(1.0);
            _qKrad_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKrad").getUnscaledValue("Wert").set(tls16BitToInt(_qKrad_));
            data.getItem("qKrad").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkw").getUnscaledValue("Wert").set(tls16BitToInt(_qPkw_));
            data.getItem("qPkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLfw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLfw").getUnscaledValue("Wert").set(tls16BitToInt(_qLfw_));
            data.getItem("qLfw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwA_));
            data.getItem("qPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkw").getUnscaledValue("Wert").set(tls16BitToInt(_qLkw_));
            data.getItem("qLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwA_));
            data.getItem("qLkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qSattelKfz").getUnscaledValue("Wert").set(tls16BitToInt(_qSattelKfz_));
            data.getItem("qSattelKfz").getItem("Güte").getScaledValue("Index").set(1.0);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qBus").getUnscaledValue("Wert").set(tls16BitToInt(_qBus_));
            data.getItem("qBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _vPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vPkwÄ_));
            data.getItem("vPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_vLkwÄ_));
            data.getItem("vLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sPkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sPkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sPkwÄ_));
            data.getItem("sPkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sLkwÄ_));
            data.getItem("sLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("v85PkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_v85PkwÄ_));
            data.getItem("v85PkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);

            // Geschwindigkeitsklassen qPkwÄ einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qPkwÄGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qLkwÄ einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qLkwÄGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            break;

        case 78 :                                                                         // Version 23
            _qKfzNk_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKfzNk").getUnscaledValue("Wert").set(tls16BitToInt(_qKfzNk_));
            data.getItem("qKfzNk").getItem("Güte").getScaledValue("Index").set(1.0);
            _qKrad_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qKrad").getUnscaledValue("Wert").set(tls16BitToInt(_qKrad_));
            data.getItem("qKrad").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkw").getUnscaledValue("Wert").set(tls16BitToInt(_qPkw_));
            data.getItem("qPkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLfw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLfw").getUnscaledValue("Wert").set(tls16BitToInt(_qLfw_));
            data.getItem("qLfw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qPkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qPkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qPkwA_));
            data.getItem("qPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkw_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkw").getUnscaledValue("Wert").set(tls16BitToInt(_qLkw_));
            data.getItem("qLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _qLkwA_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qLkwA").getUnscaledValue("Wert").set(tls16BitToInt(_qLkwA_));
            data.getItem("qLkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _qSattelKfz_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qSattelKfz").getUnscaledValue("Wert").set(tls16BitToInt(_qSattelKfz_));
            data.getItem("qSattelKfz").getItem("Güte").getScaledValue("Index").set(1.0);
            _qBus_ = deBlock.getDeData().readUnsignedLowHighByteAsInt();
            data.getItem("qBus").getUnscaledValue("Wert").set(tls16BitToInt(_qBus_));
            data.getItem("qBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _vKrad_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vKrad").getUnscaledValue("Wert").set(tls8BitToInt(_vKrad_));
            data.getItem("vKrad").getItem("Güte").getScaledValue("Index").set(1.0);
            _vPkw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vPkw").getUnscaledValue("Wert").set(tls8BitToInt(_vPkw_));
            data.getItem("vPkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLfw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLfw").getUnscaledValue("Wert").set(tls8BitToInt(_vLfw_));
            data.getItem("vLfw").getItem("Güte").getScaledValue("Index").set(1.0);
            _vPkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vPkwA").getUnscaledValue("Wert").set(tls8BitToInt(_vPkwA_));
            data.getItem("vPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLkw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLkw").getUnscaledValue("Wert").set(tls8BitToInt(_vLkw_));
            data.getItem("vLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _vLkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vLkwA").getUnscaledValue("Wert").set(tls8BitToInt(_vLkwA_));
            data.getItem("vLkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _vSattelKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vSattelKfz").getUnscaledValue("Wert").set(tls8BitToInt(_vSattelKfz_));
            data.getItem("vSattelKfz").getItem("Güte").getScaledValue("Index").set(1.0);
            _vBus_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("vBus").getUnscaledValue("Wert").set(tls8BitToInt(_vBus_));
            data.getItem("vBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _sKrad_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sKrad").getUnscaledValue("Wert").set(tls8BitToInt(_sKrad_));
            data.getItem("sKrad").getItem("Güte").getScaledValue("Index").set(1.0);
            _sPkw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sPkw").getUnscaledValue("Wert").set(tls8BitToInt(_sPkw_));
            data.getItem("sPkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLfw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLfw").getUnscaledValue("Wert").set(tls8BitToInt(_sLfw_));
            data.getItem("sLfw").getItem("Güte").getScaledValue("Index").set(1.0);
            _sPkwA_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sPkwA").getUnscaledValue("Wert").set(tls8BitToInt(_sPkwA_));
            data.getItem("sPkwA").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLkw_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLkw").getUnscaledValue("Wert").set(tls8BitToInt(_sLkw_));
            data.getItem("sLkw").getItem("Güte").getScaledValue("Index").set(1.0);
            _sLkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sLkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_sLkwÄ_));
            data.getItem("sLkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);
            _sSattelKfz_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sSattelKfz").getUnscaledValue("Wert").set(tls8BitToInt(_sSattelKfz_));
            data.getItem("sSattelKfz").getItem("Güte").getScaledValue("Index").set(1.0);
            _sBus_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("sBus").getUnscaledValue("Wert").set(tls8BitToInt(_sBus_));
            data.getItem("sBus").getItem("Güte").getScaledValue("Index").set(1.0);
            _v85PkwÄ_ = deBlock.getDeData().readUnsignedByteAsInt();
            data.getItem("v85PkwÄ").getUnscaledValue("Wert").set(tls8BitToInt(_v85PkwÄ_));
            data.getItem("v85PkwÄ").getItem("Güte").getScaledValue("Index").set(1.0);

            // Inhalt Bytes: Geschwindigkeitsklassen einer Fahrzeugklasse Für jede Geschwindigkeitsklasse wird
            // die Anzahl der Fahrzeuge pro Zeitintervall als vorzeichenloser Wert im Bereich von 0 bis maximal
            // 32767 übertragen.Die Fahrzeugarten werden wie im Anhang 2, Kapitel 2 spezifiziert zusammengefasst.
            // Die Verkehrsstärke wird für Fahrzeugmengen kleiner 128 Fahrzeuge als 1 - Byte - Wert codiert, sonst
            // als 2 - Byte - Wert. Die Kennzeichnung erfolgt im 7. Bit des 1. Bytes(low Byte) eines
            // Verkehrsstärkewertes. Ist dieses gesetzt(1), so ist die Verkehrsstärke als 1 - Byte - Wert
            // codiert und die Anzahl Fahrzeuge ermittelt sich als Byte1  128. Ist das Bit nicht gesetzt, so ist die
            // Verkehrsstärke als 2 - Byte - Wert codiert und ermittelt sich als Byte1 + Byte2 * 128. Die Sonderregelung
            // zur Codierung der Fahrzeugmengen verhindert, dass der DE -Block insgesamt zu lang wird.
            // Geschwindigkeitsklassen qKrad einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qKradGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qPkw einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qPkwGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qLfw einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qLfwGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qPkwA einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qPkwAGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qLkw einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qLkwGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qLkwA einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qLkwAGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qSattelKfz einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qSattelKfzGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert Hinweis [KS, Logos]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            // Geschwindigkeitsklassen qBus einlesen
            count = deBlock.getDeData().readUnsignedByteAsInt();
            array = data.getArray("qBusGeschwKlasse");
            array.setLength(count);

            for (int i = 0; i < count; i++) {
                _qKlasse_ = deBlock.getDeData().readUnsignedLowOrLowHighByteAsInt();
                array.getItem(i).getUnscaledValue("Wert").set(tls16BitToInt(_qKlasse_));  // <- geaendert [KS]
                array.getItem(i).getItem("Status").getItem("Erfassung").getUnscaledValue("NichtErfasst").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMax").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlFormal").getUnscaledValue("WertMin").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMaxLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("PlLogisch").getUnscaledValue("WertMinLogisch").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Implausibel").setText("Nein");
                array.getItem(i).getItem("Status").getItem("MessWertErsetzung").getUnscaledValue("Interpoliert").setText("Nein");
                array.getItem(i).getItem("Güte").getScaledValue("Index").set(1.0);
                array.getItem(i).getItem("Güte").getUnscaledValue("Verfahren").set(0);
            }

            break;

        default :
            debug.warning("Unbekannter LVE-Langzeittyp-Typ (10 - 23): " + deBlock.getTyp());
        }

        // Ergebnisdatensatz erzeugen...
        resultData = new ResultData(_de.getDe(), dataDescription, _eakConversionModul.getTimeStamp(), data);

        return resultData;
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 03.08.15
